@@ -37,6 +37,8 @@ class Gs2AdRewardRestClient(rest.AbstractGs2RestClient):
         query_strings = {
             'contextStack': request.context_stack,
         }
+        if request.name_prefix is not None:
+            query_strings["namePrefix"] = request.name_prefix
         if request.page_token is not None:
             query_strings["pageToken"] = request.page_token
         if request.limit is not None:
@@ -113,6 +115,10 @@ class Gs2AdRewardRestClient(rest.AbstractGs2RestClient):
         }
         if request.name is not None:
             body["name"] = request.name
+        if request.description is not None:
+            body["description"] = request.description
+        if request.transaction_setting is not None:
+            body["transactionSetting"] = request.transaction_setting.to_dict()
         if request.admob is not None:
             body["admob"] = request.admob.to_dict()
         if request.unity_ad is not None:
@@ -122,8 +128,6 @@ class Gs2AdRewardRestClient(rest.AbstractGs2RestClient):
                 item.to_dict()
                 for item in request.app_lovin_maxes
             ]
-        if request.description is not None:
-            body["description"] = request.description
         if request.acquire_point_script is not None:
             body["acquirePointScript"] = request.acquire_point_script.to_dict()
         if request.consume_point_script is not None:
@@ -350,6 +354,8 @@ class Gs2AdRewardRestClient(rest.AbstractGs2RestClient):
         }
         if request.description is not None:
             body["description"] = request.description
+        if request.transaction_setting is not None:
+            body["transactionSetting"] = request.transaction_setting.to_dict()
         if request.admob is not None:
             body["admob"] = request.admob.to_dict()
         if request.unity_ad is not None:
