@@ -20,9 +20,14 @@ from .model import *
 class DescribeNamespacesRequest(core.Gs2Request):
 
     context_stack: str = None
+    name_prefix: str = None
     page_token: str = None
     limit: int = None
 
+    def with_name_prefix(self, name_prefix: str) -> DescribeNamespacesRequest:
+        self.name_prefix = name_prefix
+        return self
+
     def with_page_token(self, page_token: str) -> DescribeNamespacesRequest:
         self.page_token = page_token
         return self
@@ -50,11 +55,13 @@ class DescribeNamespacesRequest(core.Gs2Request):
         if data is None:
             return None
         return DescribeNamespacesRequest()\
+            .with_name_prefix(data.get('namePrefix'))\
             .with_page_token(data.get('pageToken'))\
             .with_limit(data.get('limit'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
+            "namePrefix": self.name_prefix,
             "pageToken": self.page_token,
             "limit": self.limit,
         }
@@ -65,6 +72,7 @@ class CreateNamespaceRequest(core.Gs2Request):
     context_stack: str = None
     name: str = None
     description: str = None
+    transaction_setting: TransactionSetting = None
     apply_buff_script: ScriptSetting = None
     log_setting: LogSetting = None
 
@@ -76,6 +84,10 @@ class CreateNamespaceRequest(core.Gs2Request):
         self.description = description
         return self
 
+    def with_transaction_setting(self, transaction_setting: TransactionSetting) -> CreateNamespaceRequest:
+        self.transaction_setting = transaction_setting
+        return self
+
     def with_apply_buff_script(self, apply_buff_script: ScriptSetting) -> CreateNamespaceRequest:
         self.apply_buff_script = apply_buff_script
         return self
@@ -105,6 +117,7 @@ class CreateNamespaceRequest(core.Gs2Request):
         return CreateNamespaceRequest()\
             .with_name(data.get('name'))\
             .with_description(data.get('description'))\
+            .with_transaction_setting(TransactionSetting.from_dict(data.get('transactionSetting')))\
             .with_apply_buff_script(ScriptSetting.from_dict(data.get('applyBuffScript')))\
             .with_log_setting(LogSetting.from_dict(data.get('logSetting')))
 
@@ -112,6 +125,7 @@ class CreateNamespaceRequest(core.Gs2Request):
         return {
             "name": self.name,
             "description": self.description,
+            "transactionSetting": self.transaction_setting.to_dict() if self.transaction_setting else None,
             "applyBuffScript": self.apply_buff_script.to_dict() if self.apply_buff_script else None,
             "logSetting": self.log_setting.to_dict() if self.log_setting else None,
         }
@@ -194,6 +208,7 @@ class UpdateNamespaceRequest(core.Gs2Request):
     context_stack: str = None
     namespace_name: str = None
     description: str = None
+    transaction_setting: TransactionSetting = None
     apply_buff_script: ScriptSetting = None
     log_setting: LogSetting = None
 
@@ -205,6 +220,10 @@ class UpdateNamespaceRequest(core.Gs2Request):
         self.description = description
         return self
 
+    def with_transaction_setting(self, transaction_setting: TransactionSetting) -> UpdateNamespaceRequest:
+        self.transaction_setting = transaction_setting
+        return self
+
     def with_apply_buff_script(self, apply_buff_script: ScriptSetting) -> UpdateNamespaceRequest:
         self.apply_buff_script = apply_buff_script
         return self
@@ -234,6 +253,7 @@ class UpdateNamespaceRequest(core.Gs2Request):
         return UpdateNamespaceRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_description(data.get('description'))\
+            .with_transaction_setting(TransactionSetting.from_dict(data.get('transactionSetting')))\
             .with_apply_buff_script(ScriptSetting.from_dict(data.get('applyBuffScript')))\
             .with_log_setting(LogSetting.from_dict(data.get('logSetting')))
 
@@ -241,6 +261,7 @@ class UpdateNamespaceRequest(core.Gs2Request):
         return {
             "namespaceName": self.namespace_name,
             "description": self.description,
+            "transactionSetting": self.transaction_setting.to_dict() if self.transaction_setting else None,
             "applyBuffScript": self.apply_buff_script.to_dict() if self.apply_buff_script else None,
             "logSetting": self.log_setting.to_dict() if self.log_setting else None,
         }
@@ -709,6 +730,7 @@ class DescribeBuffEntryModelMastersRequest(core.Gs2Request):
 
     context_stack: str = None
     namespace_name: str = None
+    name_prefix: str = None
     page_token: str = None
     limit: int = None
 
@@ -716,6 +738,10 @@ class DescribeBuffEntryModelMastersRequest(core.Gs2Request):
         self.namespace_name = namespace_name
         return self
 
+    def with_name_prefix(self, name_prefix: str) -> DescribeBuffEntryModelMastersRequest:
+        self.name_prefix = name_prefix
+        return self
+
     def with_page_token(self, page_token: str) -> DescribeBuffEntryModelMastersRequest:
         self.page_token = page_token
         return self
@@ -744,12 +770,14 @@ class DescribeBuffEntryModelMastersRequest(core.Gs2Request):
             return None
         return DescribeBuffEntryModelMastersRequest()\
             .with_namespace_name(data.get('namespaceName'))\
+            .with_name_prefix(data.get('namePrefix'))\
             .with_page_token(data.get('pageToken'))\
             .with_limit(data.get('limit'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
+            "namePrefix": self.name_prefix,
             "pageToken": self.page_token,
             "limit": self.limit,
         }
@@ -1044,7 +1072,6 @@ class ApplyBuffRequest(core.Gs2Request):
     context_stack: str = None
     namespace_name: str = None
     access_token: str = None
-    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> ApplyBuffRequest:
         self.namespace_name = namespace_name
@@ -1054,10 +1081,6 @@ class ApplyBuffRequest(core.Gs2Request):
         self.access_token = access_token
         return self
 
-    def with_duplication_avoider(self, duplication_avoider: str) -> ApplyBuffRequest:
-        self.duplication_avoider = duplication_avoider
-        return self
-
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1093,7 +1116,6 @@ class ApplyBuffByUserIdRequest(core.Gs2Request):
     namespace_name: str = None
     user_id: str = None
     time_offset_token: str = None
-    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> ApplyBuffByUserIdRequest:
         self.namespace_name = namespace_name
@@ -1107,10 +1129,6 @@ class ApplyBuffByUserIdRequest(core.Gs2Request):
         self.time_offset_token = time_offset_token
         return self
 
-    def with_duplication_avoider(self, duplication_avoider: str) -> ApplyBuffByUserIdRequest:
-        self.duplication_avoider = duplication_avoider
-        return self
-
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
