@@ -37,6 +37,8 @@ class Gs2BuffRestClient(rest.AbstractGs2RestClient):
         query_strings = {
             'contextStack': request.context_stack,
         }
+        if request.name_prefix is not None:
+            query_strings["namePrefix"] = request.name_prefix
         if request.page_token is not None:
             query_strings["pageToken"] = request.page_token
         if request.limit is not None:
@@ -115,6 +117,8 @@ class Gs2BuffRestClient(rest.AbstractGs2RestClient):
             body["name"] = request.name
         if request.description is not None:
             body["description"] = request.description
+        if request.transaction_setting is not None:
+            body["transactionSetting"] = request.transaction_setting.to_dict()
         if request.apply_buff_script is not None:
             body["applyBuffScript"] = request.apply_buff_script.to_dict()
         if request.log_setting is not None:
@@ -337,6 +341,8 @@ class Gs2BuffRestClient(rest.AbstractGs2RestClient):
         }
         if request.description is not None:
             body["description"] = request.description
+        if request.transaction_setting is not None:
+            body["transactionSetting"] = request.transaction_setting.to_dict()
         if request.apply_buff_script is not None:
             body["applyBuffScript"] = request.apply_buff_script.to_dict()
         if request.log_setting is not None:
@@ -1221,6 +1227,8 @@ class Gs2BuffRestClient(rest.AbstractGs2RestClient):
         query_strings = {
             'contextStack': request.context_stack,
         }
+        if request.name_prefix is not None:
+            query_strings["namePrefix"] = request.name_prefix
         if request.page_token is not None:
             query_strings["pageToken"] = request.page_token
         if request.limit is not None:
@@ -1627,8 +1635,6 @@ class Gs2BuffRestClient(rest.AbstractGs2RestClient):
             headers["X-GS2-REQUEST-ID"] = request.request_id
         if request.access_token:
             headers["X-GS2-ACCESS-TOKEN"] = request.access_token
-        if request.duplication_avoider:
-            headers["X-GS2-DUPLICATION-AVOIDER"] = request.duplication_avoider
         _job = rest.NetworkJob(
             url=url,
             method='POST',
@@ -1702,8 +1708,6 @@ class Gs2BuffRestClient(rest.AbstractGs2RestClient):
 
         if request.request_id:
             headers["X-GS2-REQUEST-ID"] = request.request_id
-        if request.duplication_avoider:
-            headers["X-GS2-DUPLICATION-AVOIDER"] = request.duplication_avoider
         if request.time_offset_token:
             headers["X-GS2-TIME-OFFSET-TOKEN"] = request.time_offset_token
         _job = rest.NetworkJob(
