@@ -19,47 +19,6 @@ from typing import *
 from gs2 import core
 
 
-class OutputField(core.Gs2Model):
-    name: str = None
-    field_name: str = None
-
-    def with_name(self, name: str) -> OutputField:
-        self.name = name
-        return self
-
-    def with_field_name(self, field_name: str) -> OutputField:
-        self.field_name = field_name
-        return self
-
-    def get(self, key, default=None):
-        items = self.to_dict()
-        if key in items.keys():
-            return items[key]
-        return default
-
-    def __getitem__(self, key):
-        items = self.to_dict()
-        if key in items.keys():
-            return items[key]
-        return None
-
-    @staticmethod
-    def from_dict(
-        data: Dict[str, Any],
-    ) -> Optional[OutputField]:
-        if data is None:
-            return None
-        return OutputField()\
-            .with_name(data.get('name'))\
-            .with_field_name(data.get('fieldName'))
-
-    def to_dict(self) -> Dict[str, Any]:
-        return {
-            "name": self.name,
-            "fieldName": self.field_name,
-        }
-
-
 class GitHubCheckoutSetting(core.Gs2Model):
     api_key_id: str = None
     repository_name: str = None
@@ -136,6 +95,95 @@ class GitHubCheckoutSetting(core.Gs2Model):
         }
 
 
+class ChangeSet(core.Gs2Model):
+    resource_name: str = None
+    resource_type: str = None
+    operation: str = None
+
+    def with_resource_name(self, resource_name: str) -> ChangeSet:
+        self.resource_name = resource_name
+        return self
+
+    def with_resource_type(self, resource_type: str) -> ChangeSet:
+        self.resource_type = resource_type
+        return self
+
+    def with_operation(self, operation: str) -> ChangeSet:
+        self.operation = operation
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[ChangeSet]:
+        if data is None:
+            return None
+        return ChangeSet()\
+            .with_resource_name(data.get('resourceName'))\
+            .with_resource_type(data.get('resourceType'))\
+            .with_operation(data.get('operation'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "resourceName": self.resource_name,
+            "resourceType": self.resource_type,
+            "operation": self.operation,
+        }
+
+
+class OutputField(core.Gs2Model):
+    name: str = None
+    field_name: str = None
+
+    def with_name(self, name: str) -> OutputField:
+        self.name = name
+        return self
+
+    def with_field_name(self, field_name: str) -> OutputField:
+        self.field_name = field_name
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[OutputField]:
+        if data is None:
+            return None
+        return OutputField()\
+            .with_name(data.get('name'))\
+            .with_field_name(data.get('fieldName'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "name": self.name,
+            "fieldName": self.field_name,
+        }
+
+
 class Output(core.Gs2Model):
     output_id: str = None
     name: str = None
@@ -253,6 +301,7 @@ class Event(core.Gs2Model):
     type: str = None
     message: str = None
     event_at: int = None
+    revision: int = None
 
     def with_event_id(self, event_id: str) -> Event:
         self.event_id = event_id
@@ -278,6 +327,10 @@ class Event(core.Gs2Model):
         self.event_at = event_at
         return self
 
+    def with_revision(self, revision: int) -> Event:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -357,7 +410,8 @@ class Event(core.Gs2Model):
             .with_resource_name(data.get('resourceName'))\
             .with_type(data.get('type'))\
             .with_message(data.get('message'))\
-            .with_event_at(data.get('eventAt'))
+            .with_event_at(data.get('eventAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -367,6 +421,7 @@ class Event(core.Gs2Model):
             "type": self.type,
             "message": self.message,
             "eventAt": self.event_at,
+            "revision": self.revision,
         }
 
 
@@ -508,13 +563,13 @@ class Resource(core.Gs2Model):
             .with_response(data.get('response'))\
             .with_rollback_context(data.get('rollbackContext'))\
             .with_rollback_request(data.get('rollbackRequest'))\
-            .with_rollback_after([
+            .with_rollback_after(None if data.get('rollbackAfter') is None else [
                 data.get('rollbackAfter')[i]
-                for i in range(len(data.get('rollbackAfter')) if data.get('rollbackAfter') else 0)
+                for i in range(len(data.get('rollbackAfter')))
             ])\
-            .with_output_fields([
+            .with_output_fields(None if data.get('outputFields') is None else [
                 OutputField.from_dict(data.get('outputFields')[i])
-                for i in range(len(data.get('outputFields')) if data.get('outputFields') else 0)
+                for i in range(len(data.get('outputFields')))
             ])\
             .with_work_id(data.get('workId'))\
             .with_created_at(data.get('createdAt'))
@@ -528,13 +583,13 @@ class Resource(core.Gs2Model):
             "response": self.response,
             "rollbackContext": self.rollback_context,
             "rollbackRequest": self.rollback_request,
-            "rollbackAfter": [
+            "rollbackAfter": None if self.rollback_after is None else [
                 self.rollback_after[i]
-                for i in range(len(self.rollback_after) if self.rollback_after else 0)
+                for i in range(len(self.rollback_after))
             ],
-            "outputFields": [
+            "outputFields": None if self.output_fields is None else [
                 self.output_fields[i].to_dict() if self.output_fields[i] else None
-                for i in range(len(self.output_fields) if self.output_fields else 0)
+                for i in range(len(self.output_fields))
             ],
             "workId": self.work_id,
             "createdAt": self.created_at,
@@ -549,6 +604,7 @@ class Stack(core.Gs2Model):
     status: str = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_stack_id(self, stack_id: str) -> Stack:
         self.stack_id = stack_id
@@ -578,6 +634,10 @@ class Stack(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Stack:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -646,7 +706,8 @@ class Stack(core.Gs2Model):
             .with_template(data.get('template'))\
             .with_status(data.get('status'))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -657,4 +718,5 @@ class Stack(core.Gs2Model):
             "status": self.status,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
\ No newline at end of file
