@@ -20,9 +20,14 @@ from .model import *
 class DescribeStacksRequest(core.Gs2Request):
 
     context_stack: str = None
+    name_prefix: str = None
     page_token: str = None
     limit: int = None
 
+    def with_name_prefix(self, name_prefix: str) -> DescribeStacksRequest:
+        self.name_prefix = name_prefix
+        return self
+
     def with_page_token(self, page_token: str) -> DescribeStacksRequest:
         self.page_token = page_token
         return self
@@ -50,11 +55,13 @@ class DescribeStacksRequest(core.Gs2Request):
         if data is None:
             return None
         return DescribeStacksRequest()\
+            .with_name_prefix(data.get('namePrefix'))\
             .with_page_token(data.get('pageToken'))\
             .with_limit(data.get('limit'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
+            "namePrefix": self.name_prefix,
             "pageToken": self.page_token,
             "limit": self.limit,
         }
