@@ -20,9 +20,14 @@ from .model import *
 class DescribeNamespacesRequest(core.Gs2Request):
 
     context_stack: str = None
+    name_prefix: str = None
     page_token: str = None
     limit: int = None
 
+    def with_name_prefix(self, name_prefix: str) -> DescribeNamespacesRequest:
+        self.name_prefix = name_prefix
+        return self
+
     def with_page_token(self, page_token: str) -> DescribeNamespacesRequest:
         self.page_token = page_token
         return self
@@ -50,11 +55,13 @@ class DescribeNamespacesRequest(core.Gs2Request):
         if data is None:
             return None
         return DescribeNamespacesRequest()\
+            .with_name_prefix(data.get('namePrefix'))\
             .with_page_token(data.get('pageToken'))\
             .with_limit(data.get('limit'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
+            "namePrefix": self.name_prefix,
             "pageToken": self.page_token,
             "limit": self.limit,
         }
@@ -65,6 +72,7 @@ class CreateNamespaceRequest(core.Gs2Request):
     context_stack: str = None
     name: str = None
     description: str = None
+    transaction_setting: TransactionSetting = None
     entry_script: ScriptSetting = None
     duplicate_entry_script: str = None
     log_setting: LogSetting = None
@@ -77,6 +85,10 @@ class CreateNamespaceRequest(core.Gs2Request):
         self.description = description
         return self
 
+    def with_transaction_setting(self, transaction_setting: TransactionSetting) -> CreateNamespaceRequest:
+        self.transaction_setting = transaction_setting
+        return self
+
     def with_entry_script(self, entry_script: ScriptSetting) -> CreateNamespaceRequest:
         self.entry_script = entry_script
         return self
@@ -110,6 +122,7 @@ class CreateNamespaceRequest(core.Gs2Request):
         return CreateNamespaceRequest()\
             .with_name(data.get('name'))\
             .with_description(data.get('description'))\
+            .with_transaction_setting(TransactionSetting.from_dict(data.get('transactionSetting')))\
             .with_entry_script(ScriptSetting.from_dict(data.get('entryScript')))\
             .with_duplicate_entry_script(data.get('duplicateEntryScript'))\
             .with_log_setting(LogSetting.from_dict(data.get('logSetting')))
@@ -118,6 +131,7 @@ class CreateNamespaceRequest(core.Gs2Request):
         return {
             "name": self.name,
             "description": self.description,
+            "transactionSetting": self.transaction_setting.to_dict() if self.transaction_setting else None,
             "entryScript": self.entry_script.to_dict() if self.entry_script else None,
             "duplicateEntryScript": self.duplicate_entry_script,
             "logSetting": self.log_setting.to_dict() if self.log_setting else None,
@@ -201,6 +215,7 @@ class UpdateNamespaceRequest(core.Gs2Request):
     context_stack: str = None
     namespace_name: str = None
     description: str = None
+    transaction_setting: TransactionSetting = None
     entry_script: ScriptSetting = None
     duplicate_entry_script: str = None
     log_setting: LogSetting = None
@@ -213,6 +228,10 @@ class UpdateNamespaceRequest(core.Gs2Request):
         self.description = description
         return self
 
+    def with_transaction_setting(self, transaction_setting: TransactionSetting) -> UpdateNamespaceRequest:
+        self.transaction_setting = transaction_setting
+        return self
+
     def with_entry_script(self, entry_script: ScriptSetting) -> UpdateNamespaceRequest:
         self.entry_script = entry_script
         return self
@@ -246,6 +265,7 @@ class UpdateNamespaceRequest(core.Gs2Request):
         return UpdateNamespaceRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_description(data.get('description'))\
+            .with_transaction_setting(TransactionSetting.from_dict(data.get('transactionSetting')))\
             .with_entry_script(ScriptSetting.from_dict(data.get('entryScript')))\
             .with_duplicate_entry_script(data.get('duplicateEntryScript'))\
             .with_log_setting(LogSetting.from_dict(data.get('logSetting')))
@@ -254,6 +274,7 @@ class UpdateNamespaceRequest(core.Gs2Request):
         return {
             "namespaceName": self.namespace_name,
             "description": self.description,
+            "transactionSetting": self.transaction_setting.to_dict() if self.transaction_setting else None,
             "entryScript": self.entry_script.to_dict() if self.entry_script else None,
             "duplicateEntryScript": self.duplicate_entry_script,
             "logSetting": self.log_setting.to_dict() if self.log_setting else None,
@@ -723,6 +744,7 @@ class DescribeEntryModelMastersRequest(core.Gs2Request):
 
     context_stack: str = None
     namespace_name: str = None
+    name_prefix: str = None
     page_token: str = None
     limit: int = None
 
@@ -730,6 +752,10 @@ class DescribeEntryModelMastersRequest(core.Gs2Request):
         self.namespace_name = namespace_name
         return self
 
+    def with_name_prefix(self, name_prefix: str) -> DescribeEntryModelMastersRequest:
+        self.name_prefix = name_prefix
+        return self
+
     def with_page_token(self, page_token: str) -> DescribeEntryModelMastersRequest:
         self.page_token = page_token
         return self
@@ -758,12 +784,14 @@ class DescribeEntryModelMastersRequest(core.Gs2Request):
             return None
         return DescribeEntryModelMastersRequest()\
             .with_namespace_name(data.get('namespaceName'))\
+            .with_name_prefix(data.get('namePrefix'))\
             .with_page_token(data.get('pageToken'))\
             .with_limit(data.get('limit'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
+            "namePrefix": self.name_prefix,
             "pageToken": self.page_token,
             "limit": self.limit,
         }
