@@ -20,9 +20,14 @@ from .model import *
 class DescribeNamespacesRequest(core.Gs2Request):
 
     context_stack: str = None
+    name_prefix: str = None
     page_token: str = None
     limit: int = None
 
+    def with_name_prefix(self, name_prefix: str) -> DescribeNamespacesRequest:
+        self.name_prefix = name_prefix
+        return self
+
     def with_page_token(self, page_token: str) -> DescribeNamespacesRequest:
         self.page_token = page_token
         return self
@@ -50,11 +55,13 @@ class DescribeNamespacesRequest(core.Gs2Request):
         if data is None:
             return None
         return DescribeNamespacesRequest()\
+            .with_name_prefix(data.get('namePrefix'))\
             .with_page_token(data.get('pageToken'))\
             .with_limit(data.get('limit'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
+            "namePrefix": self.name_prefix,
             "pageToken": self.page_token,
             "limit": self.limit,
         }
@@ -65,6 +72,7 @@ class CreateNamespaceRequest(core.Gs2Request):
     context_stack: str = None
     name: str = None
     description: str = None
+    transaction_setting: TransactionSetting = None
     assume_user_id: str = None
     auto_run_stamp_sheet_notification: NotificationSetting = None
     auto_run_transaction_notification: NotificationSetting = None
@@ -78,6 +86,10 @@ class CreateNamespaceRequest(core.Gs2Request):
         self.description = description
         return self
 
+    def with_transaction_setting(self, transaction_setting: TransactionSetting) -> CreateNamespaceRequest:
+        self.transaction_setting = transaction_setting
+        return self
+
     def with_assume_user_id(self, assume_user_id: str) -> CreateNamespaceRequest:
         self.assume_user_id = assume_user_id
         return self
@@ -115,6 +127,7 @@ class CreateNamespaceRequest(core.Gs2Request):
         return CreateNamespaceRequest()\
             .with_name(data.get('name'))\
             .with_description(data.get('description'))\
+            .with_transaction_setting(TransactionSetting.from_dict(data.get('transactionSetting')))\
             .with_assume_user_id(data.get('assumeUserId'))\
             .with_auto_run_stamp_sheet_notification(NotificationSetting.from_dict(data.get('autoRunStampSheetNotification')))\
             .with_auto_run_transaction_notification(NotificationSetting.from_dict(data.get('autoRunTransactionNotification')))\
@@ -124,6 +137,7 @@ class CreateNamespaceRequest(core.Gs2Request):
         return {
             "name": self.name,
             "description": self.description,
+            "transactionSetting": self.transaction_setting.to_dict() if self.transaction_setting else None,
             "assumeUserId": self.assume_user_id,
             "autoRunStampSheetNotification": self.auto_run_stamp_sheet_notification.to_dict() if self.auto_run_stamp_sheet_notification else None,
             "autoRunTransactionNotification": self.auto_run_transaction_notification.to_dict() if self.auto_run_transaction_notification else None,
@@ -208,6 +222,7 @@ class UpdateNamespaceRequest(core.Gs2Request):
     context_stack: str = None
     namespace_name: str = None
     description: str = None
+    transaction_setting: TransactionSetting = None
     assume_user_id: str = None
     auto_run_stamp_sheet_notification: NotificationSetting = None
     auto_run_transaction_notification: NotificationSetting = None
@@ -221,6 +236,10 @@ class UpdateNamespaceRequest(core.Gs2Request):
         self.description = description
         return self
 
+    def with_transaction_setting(self, transaction_setting: TransactionSetting) -> UpdateNamespaceRequest:
+        self.transaction_setting = transaction_setting
+        return self
+
     def with_assume_user_id(self, assume_user_id: str) -> UpdateNamespaceRequest:
         self.assume_user_id = assume_user_id
         return self
@@ -258,6 +277,7 @@ class UpdateNamespaceRequest(core.Gs2Request):
         return UpdateNamespaceRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_description(data.get('description'))\
+            .with_transaction_setting(TransactionSetting.from_dict(data.get('transactionSetting')))\
             .with_assume_user_id(data.get('assumeUserId'))\
             .with_auto_run_stamp_sheet_notification(NotificationSetting.from_dict(data.get('autoRunStampSheetNotification')))\
             .with_auto_run_transaction_notification(NotificationSetting.from_dict(data.get('autoRunTransactionNotification')))\
@@ -267,6 +287,7 @@ class UpdateNamespaceRequest(core.Gs2Request):
         return {
             "namespaceName": self.namespace_name,
             "description": self.description,
+            "transactionSetting": self.transaction_setting.to_dict() if self.transaction_setting else None,
             "assumeUserId": self.assume_user_id,
             "autoRunStampSheetNotification": self.auto_run_stamp_sheet_notification.to_dict() if self.auto_run_stamp_sheet_notification else None,
             "autoRunTransactionNotification": self.auto_run_transaction_notification.to_dict() if self.auto_run_transaction_notification else None,
@@ -343,6 +364,7 @@ class DescribeDistributorModelMastersRequest(core.Gs2Request):
 
     context_stack: str = None
     namespace_name: str = None
+    name_prefix: str = None
     page_token: str = None
     limit: int = None
 
@@ -350,6 +372,10 @@ class DescribeDistributorModelMastersRequest(core.Gs2Request):
         self.namespace_name = namespace_name
         return self
 
+    def with_name_prefix(self, name_prefix: str) -> DescribeDistributorModelMastersRequest:
+        self.name_prefix = name_prefix
+        return self
+
     def with_page_token(self, page_token: str) -> DescribeDistributorModelMastersRequest:
         self.page_token = page_token
         return self
@@ -378,12 +404,14 @@ class DescribeDistributorModelMastersRequest(core.Gs2Request):
             return None
         return DescribeDistributorModelMastersRequest()\
             .with_namespace_name(data.get('namespaceName'))\
+            .with_name_prefix(data.get('namePrefix'))\
             .with_page_token(data.get('pageToken'))\
             .with_limit(data.get('limit'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
+            "namePrefix": self.name_prefix,
             "pageToken": self.page_token,
             "limit": self.limit,
         }
@@ -1532,7 +1560,6 @@ class FreezeMasterDataRequest(core.Gs2Request):
     context_stack: str = None
     namespace_name: str = None
     access_token: str = None
-    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> FreezeMasterDataRequest:
         self.namespace_name = namespace_name
@@ -1542,10 +1569,6 @@ class FreezeMasterDataRequest(core.Gs2Request):
         self.access_token = access_token
         return self
 
-    def with_duplication_avoider(self, duplication_avoider: str) -> FreezeMasterDataRequest:
-        self.duplication_avoider = duplication_avoider
-        return self
-
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1581,7 +1604,6 @@ class FreezeMasterDataByUserIdRequest(core.Gs2Request):
     namespace_name: str = None
     user_id: str = None
     time_offset_token: str = None
-    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> FreezeMasterDataByUserIdRequest:
         self.namespace_name = namespace_name
@@ -1595,10 +1617,6 @@ class FreezeMasterDataByUserIdRequest(core.Gs2Request):
         self.time_offset_token = time_offset_token
         return self
 
-    def with_duplication_avoider(self, duplication_avoider: str) -> FreezeMasterDataByUserIdRequest:
-        self.duplication_avoider = duplication_avoider
-        return self
-
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1688,7 +1706,6 @@ class FreezeMasterDataBySignedTimestampRequest(core.Gs2Request):
     body: str = None
     signature: str = None
     key_id: str = None
-    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> FreezeMasterDataBySignedTimestampRequest:
         self.namespace_name = namespace_name
@@ -1710,10 +1727,6 @@ class FreezeMasterDataBySignedTimestampRequest(core.Gs2Request):
         self.key_id = key_id
         return self
 
-    def with_duplication_avoider(self, duplication_avoider: str) -> FreezeMasterDataBySignedTimestampRequest:
-        self.duplication_avoider = duplication_avoider
-        return self
-
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1755,7 +1768,6 @@ class FreezeMasterDataByTimestampRequest(core.Gs2Request):
     namespace_name: str = None
     access_token: str = None
     timestamp: int = None
-    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> FreezeMasterDataByTimestampRequest:
         self.namespace_name = namespace_name
@@ -1769,10 +1781,6 @@ class FreezeMasterDataByTimestampRequest(core.Gs2Request):
         self.timestamp = timestamp
         return self
 
-    def with_duplication_avoider(self, duplication_avoider: str) -> FreezeMasterDataByTimestampRequest:
-        self.duplication_avoider = duplication_avoider
-        return self
-
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
