@@ -20,9 +20,14 @@ from .model import *
 class DescribeNamespacesRequest(core.Gs2Request):
 
     context_stack: str = None
+    name_prefix: str = None
     page_token: str = None
     limit: int = None
 
+    def with_name_prefix(self, name_prefix: str) -> DescribeNamespacesRequest:
+        self.name_prefix = name_prefix
+        return self
+
     def with_page_token(self, page_token: str) -> DescribeNamespacesRequest:
         self.page_token = page_token
         return self
@@ -50,11 +55,13 @@ class DescribeNamespacesRequest(core.Gs2Request):
         if data is None:
             return None
         return DescribeNamespacesRequest()\
+            .with_name_prefix(data.get('namePrefix'))\
             .with_page_token(data.get('pageToken'))\
             .with_limit(data.get('limit'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
+            "namePrefix": self.name_prefix,
             "pageToken": self.page_token,
             "limit": self.limit,
         }
@@ -765,6 +772,7 @@ class DescribeRateModelMastersRequest(core.Gs2Request):
 
     context_stack: str = None
     namespace_name: str = None
+    name_prefix: str = None
     page_token: str = None
     limit: int = None
 
@@ -772,6 +780,10 @@ class DescribeRateModelMastersRequest(core.Gs2Request):
         self.namespace_name = namespace_name
         return self
 
+    def with_name_prefix(self, name_prefix: str) -> DescribeRateModelMastersRequest:
+        self.name_prefix = name_prefix
+        return self
+
     def with_page_token(self, page_token: str) -> DescribeRateModelMastersRequest:
         self.page_token = page_token
         return self
@@ -800,12 +812,14 @@ class DescribeRateModelMastersRequest(core.Gs2Request):
             return None
         return DescribeRateModelMastersRequest()\
             .with_namespace_name(data.get('namespaceName'))\
+            .with_name_prefix(data.get('namePrefix'))\
             .with_page_token(data.get('pageToken'))\
             .with_limit(data.get('limit'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
+            "namePrefix": self.name_prefix,
             "pageToken": self.page_token,
             "limit": self.limit,
         }
@@ -1202,6 +1216,7 @@ class DescribeUnleashRateModelMastersRequest(core.Gs2Request):
 
     context_stack: str = None
     namespace_name: str = None
+    name_prefix: str = None
     page_token: str = None
     limit: int = None
 
@@ -1209,6 +1224,10 @@ class DescribeUnleashRateModelMastersRequest(core.Gs2Request):
         self.namespace_name = namespace_name
         return self
 
+    def with_name_prefix(self, name_prefix: str) -> DescribeUnleashRateModelMastersRequest:
+        self.name_prefix = name_prefix
+        return self
+
     def with_page_token(self, page_token: str) -> DescribeUnleashRateModelMastersRequest:
         self.page_token = page_token
         return self
@@ -1237,12 +1256,14 @@ class DescribeUnleashRateModelMastersRequest(core.Gs2Request):
             return None
         return DescribeUnleashRateModelMastersRequest()\
             .with_namespace_name(data.get('namespaceName'))\
+            .with_name_prefix(data.get('namePrefix'))\
             .with_page_token(data.get('pageToken'))\
             .with_limit(data.get('limit'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
+            "namePrefix": self.name_prefix,
             "pageToken": self.page_token,
             "limit": self.limit,
         }
