@@ -19,6 +19,89 @@ from typing import *
 from gs2 import core
 
 
+class TransactionSetting(core.Gs2Model):
+    enable_auto_run: bool = None
+    enable_atomic_commit: bool = None
+    transaction_use_distributor: bool = None
+    commit_script_result_in_use_distributor: bool = None
+    acquire_action_use_job_queue: bool = None
+    distributor_namespace_id: str = None
+    key_id: str = None
+    queue_namespace_id: str = None
+
+    def with_enable_auto_run(self, enable_auto_run: bool) -> TransactionSetting:
+        self.enable_auto_run = enable_auto_run
+        return self
+
+    def with_enable_atomic_commit(self, enable_atomic_commit: bool) -> TransactionSetting:
+        self.enable_atomic_commit = enable_atomic_commit
+        return self
+
+    def with_transaction_use_distributor(self, transaction_use_distributor: bool) -> TransactionSetting:
+        self.transaction_use_distributor = transaction_use_distributor
+        return self
+
+    def with_commit_script_result_in_use_distributor(self, commit_script_result_in_use_distributor: bool) -> TransactionSetting:
+        self.commit_script_result_in_use_distributor = commit_script_result_in_use_distributor
+        return self
+
+    def with_acquire_action_use_job_queue(self, acquire_action_use_job_queue: bool) -> TransactionSetting:
+        self.acquire_action_use_job_queue = acquire_action_use_job_queue
+        return self
+
+    def with_distributor_namespace_id(self, distributor_namespace_id: str) -> TransactionSetting:
+        self.distributor_namespace_id = distributor_namespace_id
+        return self
+
+    def with_key_id(self, key_id: str) -> TransactionSetting:
+        self.key_id = key_id
+        return self
+
+    def with_queue_namespace_id(self, queue_namespace_id: str) -> TransactionSetting:
+        self.queue_namespace_id = queue_namespace_id
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[TransactionSetting]:
+        if data is None:
+            return None
+        return TransactionSetting()\
+            .with_enable_auto_run(data.get('enableAutoRun'))\
+            .with_enable_atomic_commit(data.get('enableAtomicCommit'))\
+            .with_transaction_use_distributor(data.get('transactionUseDistributor'))\
+            .with_commit_script_result_in_use_distributor(data.get('commitScriptResultInUseDistributor'))\
+            .with_acquire_action_use_job_queue(data.get('acquireActionUseJobQueue'))\
+            .with_distributor_namespace_id(data.get('distributorNamespaceId'))\
+            .with_key_id(data.get('keyId'))\
+            .with_queue_namespace_id(data.get('queueNamespaceId'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "enableAutoRun": self.enable_auto_run,
+            "enableAtomicCommit": self.enable_atomic_commit,
+            "transactionUseDistributor": self.transaction_use_distributor,
+            "commitScriptResultInUseDistributor": self.commit_script_result_in_use_distributor,
+            "acquireActionUseJobQueue": self.acquire_action_use_job_queue,
+            "distributorNamespaceId": self.distributor_namespace_id,
+            "keyId": self.key_id,
+            "queueNamespaceId": self.queue_namespace_id,
+        }
+
+
 class LogSetting(core.Gs2Model):
     logging_namespace_id: str = None
 
@@ -57,6 +140,7 @@ class NotificationSetting(core.Gs2Model):
     gateway_namespace_id: str = None
     enable_transfer_mobile_notification: bool = None
     sound: str = None
+    enable: str = None
 
     def with_gateway_namespace_id(self, gateway_namespace_id: str) -> NotificationSetting:
         self.gateway_namespace_id = gateway_namespace_id
@@ -70,6 +154,10 @@ class NotificationSetting(core.Gs2Model):
         self.sound = sound
         return self
 
+    def with_enable(self, enable: str) -> NotificationSetting:
+        self.enable = enable
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -91,13 +179,15 @@ class NotificationSetting(core.Gs2Model):
         return NotificationSetting()\
             .with_gateway_namespace_id(data.get('gatewayNamespaceId'))\
             .with_enable_transfer_mobile_notification(data.get('enableTransferMobileNotification'))\
-            .with_sound(data.get('sound'))
+            .with_sound(data.get('sound'))\
+            .with_enable(data.get('enable'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "gatewayNamespaceId": self.gateway_namespace_id,
             "enableTransferMobileNotification": self.enable_transfer_mobile_notification,
             "sound": self.sound,
+            "enable": self.enable,
         }
 
 
@@ -207,6 +297,7 @@ class PublicProfile(core.Gs2Model):
 class ReceiveFriendRequest(core.Gs2Model):
     user_id: str = None
     target_user_id: str = None
+    public_profile: str = None
 
     def with_user_id(self, user_id: str) -> ReceiveFriendRequest:
         self.user_id = user_id
@@ -216,6 +307,10 @@ class ReceiveFriendRequest(core.Gs2Model):
         self.target_user_id = target_user_id
         return self
 
+    def with_public_profile(self, public_profile: str) -> ReceiveFriendRequest:
+        self.public_profile = public_profile
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -243,18 +338,21 @@ class ReceiveFriendRequest(core.Gs2Model):
             return None
         return ReceiveFriendRequest()\
             .with_user_id(data.get('userId'))\
-            .with_target_user_id(data.get('targetUserId'))
+            .with_target_user_id(data.get('targetUserId'))\
+            .with_public_profile(data.get('publicProfile'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "userId": self.user_id,
             "targetUserId": self.target_user_id,
+            "publicProfile": self.public_profile,
         }
 
 
 class SendFriendRequest(core.Gs2Model):
     user_id: str = None
     target_user_id: str = None
+    public_profile: str = None
 
     def with_user_id(self, user_id: str) -> SendFriendRequest:
         self.user_id = user_id
@@ -264,6 +362,10 @@ class SendFriendRequest(core.Gs2Model):
         self.target_user_id = target_user_id
         return self
 
+    def with_public_profile(self, public_profile: str) -> SendFriendRequest:
+        self.public_profile = public_profile
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -291,18 +393,21 @@ class SendFriendRequest(core.Gs2Model):
             return None
         return SendFriendRequest()\
             .with_user_id(data.get('userId'))\
-            .with_target_user_id(data.get('targetUserId'))
+            .with_target_user_id(data.get('targetUserId'))\
+            .with_public_profile(data.get('publicProfile'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "userId": self.user_id,
             "targetUserId": self.target_user_id,
+            "publicProfile": self.public_profile,
         }
 
 
 class FriendRequest(core.Gs2Model):
     user_id: str = None
     target_user_id: str = None
+    public_profile: str = None
 
     def with_user_id(self, user_id: str) -> FriendRequest:
         self.user_id = user_id
@@ -312,6 +417,10 @@ class FriendRequest(core.Gs2Model):
         self.target_user_id = target_user_id
         return self
 
+    def with_public_profile(self, public_profile: str) -> FriendRequest:
+        self.public_profile = public_profile
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -339,12 +448,14 @@ class FriendRequest(core.Gs2Model):
             return None
         return FriendRequest()\
             .with_user_id(data.get('userId'))\
-            .with_target_user_id(data.get('targetUserId'))
+            .with_target_user_id(data.get('targetUserId'))\
+            .with_public_profile(data.get('publicProfile'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "userId": self.user_id,
             "targetUserId": self.target_user_id,
+            "publicProfile": self.public_profile,
         }
 
 
@@ -1250,6 +1361,7 @@ class Namespace(core.Gs2Model):
     namespace_id: str = None
     name: str = None
     description: str = None
+    transaction_setting: TransactionSetting = None
     follow_script: ScriptSetting = None
     unfollow_script: ScriptSetting = None
     send_request_script: ScriptSetting = None
@@ -1281,6 +1393,10 @@ class Namespace(core.Gs2Model):
         self.description = description
         return self
 
+    def with_transaction_setting(self, transaction_setting: TransactionSetting) -> Namespace:
+        self.transaction_setting = transaction_setting
+        return self
+
     def with_follow_script(self, follow_script: ScriptSetting) -> Namespace:
         self.follow_script = follow_script
         return self
@@ -1418,6 +1534,7 @@ class Namespace(core.Gs2Model):
             .with_namespace_id(data.get('namespaceId'))\
             .with_name(data.get('name'))\
             .with_description(data.get('description'))\
+            .with_transaction_setting(TransactionSetting.from_dict(data.get('transactionSetting')))\
             .with_follow_script(ScriptSetting.from_dict(data.get('followScript')))\
             .with_unfollow_script(ScriptSetting.from_dict(data.get('unfollowScript')))\
             .with_send_request_script(ScriptSetting.from_dict(data.get('sendRequestScript')))\
@@ -1442,6 +1559,7 @@ class Namespace(core.Gs2Model):
             "namespaceId": self.namespace_id,
             "name": self.name,
             "description": self.description,
+            "transactionSetting": self.transaction_setting.to_dict() if self.transaction_setting else None,
             "followScript": self.follow_script.to_dict() if self.follow_script else None,
             "unfollowScript": self.unfollow_script.to_dict() if self.unfollow_script else None,
             "sendRequestScript": self.send_request_script.to_dict() if self.send_request_script else None,
