@@ -19,6 +19,89 @@ from typing import *
 from gs2 import core
 
 
+class TransactionSetting(core.Gs2Model):
+    enable_auto_run: bool = None
+    enable_atomic_commit: bool = None
+    transaction_use_distributor: bool = None
+    commit_script_result_in_use_distributor: bool = None
+    acquire_action_use_job_queue: bool = None
+    distributor_namespace_id: str = None
+    key_id: str = None
+    queue_namespace_id: str = None
+
+    def with_enable_auto_run(self, enable_auto_run: bool) -> TransactionSetting:
+        self.enable_auto_run = enable_auto_run
+        return self
+
+    def with_enable_atomic_commit(self, enable_atomic_commit: bool) -> TransactionSetting:
+        self.enable_atomic_commit = enable_atomic_commit
+        return self
+
+    def with_transaction_use_distributor(self, transaction_use_distributor: bool) -> TransactionSetting:
+        self.transaction_use_distributor = transaction_use_distributor
+        return self
+
+    def with_commit_script_result_in_use_distributor(self, commit_script_result_in_use_distributor: bool) -> TransactionSetting:
+        self.commit_script_result_in_use_distributor = commit_script_result_in_use_distributor
+        return self
+
+    def with_acquire_action_use_job_queue(self, acquire_action_use_job_queue: bool) -> TransactionSetting:
+        self.acquire_action_use_job_queue = acquire_action_use_job_queue
+        return self
+
+    def with_distributor_namespace_id(self, distributor_namespace_id: str) -> TransactionSetting:
+        self.distributor_namespace_id = distributor_namespace_id
+        return self
+
+    def with_key_id(self, key_id: str) -> TransactionSetting:
+        self.key_id = key_id
+        return self
+
+    def with_queue_namespace_id(self, queue_namespace_id: str) -> TransactionSetting:
+        self.queue_namespace_id = queue_namespace_id
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[TransactionSetting]:
+        if data is None:
+            return None
+        return TransactionSetting()\
+            .with_enable_auto_run(data.get('enableAutoRun'))\
+            .with_enable_atomic_commit(data.get('enableAtomicCommit'))\
+            .with_transaction_use_distributor(data.get('transactionUseDistributor'))\
+            .with_commit_script_result_in_use_distributor(data.get('commitScriptResultInUseDistributor'))\
+            .with_acquire_action_use_job_queue(data.get('acquireActionUseJobQueue'))\
+            .with_distributor_namespace_id(data.get('distributorNamespaceId'))\
+            .with_key_id(data.get('keyId'))\
+            .with_queue_namespace_id(data.get('queueNamespaceId'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "enableAutoRun": self.enable_auto_run,
+            "enableAtomicCommit": self.enable_atomic_commit,
+            "transactionUseDistributor": self.transaction_use_distributor,
+            "commitScriptResultInUseDistributor": self.commit_script_result_in_use_distributor,
+            "acquireActionUseJobQueue": self.acquire_action_use_job_queue,
+            "distributorNamespaceId": self.distributor_namespace_id,
+            "keyId": self.key_id,
+            "queueNamespaceId": self.queue_namespace_id,
+        }
+
+
 class LogSetting(core.Gs2Model):
     logging_namespace_id: str = None
 
@@ -182,6 +265,7 @@ class WebSocketSession(core.Gs2Model):
     connection_id: str = None
     namespace_name: str = None
     user_id: str = None
+    session_id: str = None
     created_at: int = None
     updated_at: int = None
     revision: int = None
@@ -202,6 +286,10 @@ class WebSocketSession(core.Gs2Model):
         self.user_id = user_id
         return self
 
+    def with_session_id(self, session_id: str) -> WebSocketSession:
+        self.session_id = session_id
+        return self
+
     def with_created_at(self, created_at: int) -> WebSocketSession:
         self.created_at = created_at
         return self
@@ -304,6 +392,7 @@ class WebSocketSession(core.Gs2Model):
             .with_connection_id(data.get('connectionId'))\
             .with_namespace_name(data.get('namespaceName'))\
             .with_user_id(data.get('userId'))\
+            .with_session_id(data.get('sessionId'))\
             .with_created_at(data.get('createdAt'))\
             .with_updated_at(data.get('updatedAt'))\
             .with_revision(data.get('revision'))
@@ -314,6 +403,7 @@ class WebSocketSession(core.Gs2Model):
             "connectionId": self.connection_id,
             "namespaceName": self.namespace_name,
             "userId": self.user_id,
+            "sessionId": self.session_id,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
             "revision": self.revision,
@@ -324,6 +414,7 @@ class Namespace(core.Gs2Model):
     namespace_id: str = None
     name: str = None
     description: str = None
+    transaction_setting: TransactionSetting = None
     firebase_secret: str = None
     log_setting: LogSetting = None
     created_at: int = None
@@ -342,6 +433,10 @@ class Namespace(core.Gs2Model):
         self.description = description
         return self
 
+    def with_transaction_setting(self, transaction_setting: TransactionSetting) -> Namespace:
+        self.transaction_setting = transaction_setting
+        return self
+
     def with_firebase_secret(self, firebase_secret: str) -> Namespace:
         self.firebase_secret = firebase_secret
         return self
@@ -427,6 +522,7 @@ class Namespace(core.Gs2Model):
             .with_namespace_id(data.get('namespaceId'))\
             .with_name(data.get('name'))\
             .with_description(data.get('description'))\
+            .with_transaction_setting(TransactionSetting.from_dict(data.get('transactionSetting')))\
             .with_firebase_secret(data.get('firebaseSecret'))\
             .with_log_setting(LogSetting.from_dict(data.get('logSetting')))\
             .with_created_at(data.get('createdAt'))\
@@ -438,6 +534,7 @@ class Namespace(core.Gs2Model):
             "namespaceId": self.namespace_id,
             "name": self.name,
             "description": self.description,
+            "transactionSetting": self.transaction_setting.to_dict() if self.transaction_setting else None,
             "firebaseSecret": self.firebase_secret,
             "logSetting": self.log_setting.to_dict() if self.log_setting else None,
             "createdAt": self.created_at,
