@@ -20,9 +20,14 @@ from .model import *
 class DescribeNamespacesRequest(core.Gs2Request):
 
     context_stack: str = None
+    name_prefix: str = None
     page_token: str = None
     limit: int = None
 
+    def with_name_prefix(self, name_prefix: str) -> DescribeNamespacesRequest:
+        self.name_prefix = name_prefix
+        return self
+
     def with_page_token(self, page_token: str) -> DescribeNamespacesRequest:
         self.page_token = page_token
         return self
@@ -50,11 +55,13 @@ class DescribeNamespacesRequest(core.Gs2Request):
         if data is None:
             return None
         return DescribeNamespacesRequest()\
+            .with_name_prefix(data.get('namePrefix'))\
             .with_page_token(data.get('pageToken'))\
             .with_limit(data.get('limit'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
+            "namePrefix": self.name_prefix,
             "pageToken": self.page_token,
             "limit": self.limit,
         }
@@ -65,6 +72,7 @@ class CreateNamespaceRequest(core.Gs2Request):
     context_stack: str = None
     name: str = None
     description: str = None
+    transaction_setting: TransactionSetting = None
     firebase_secret: str = None
     log_setting: LogSetting = None
 
@@ -76,6 +84,10 @@ class CreateNamespaceRequest(core.Gs2Request):
         self.description = description
         return self
 
+    def with_transaction_setting(self, transaction_setting: TransactionSetting) -> CreateNamespaceRequest:
+        self.transaction_setting = transaction_setting
+        return self
+
     def with_firebase_secret(self, firebase_secret: str) -> CreateNamespaceRequest:
         self.firebase_secret = firebase_secret
         return self
@@ -105,6 +117,7 @@ class CreateNamespaceRequest(core.Gs2Request):
         return CreateNamespaceRequest()\
             .with_name(data.get('name'))\
             .with_description(data.get('description'))\
+            .with_transaction_setting(TransactionSetting.from_dict(data.get('transactionSetting')))\
             .with_firebase_secret(data.get('firebaseSecret'))\
             .with_log_setting(LogSetting.from_dict(data.get('logSetting')))
 
@@ -112,6 +125,7 @@ class CreateNamespaceRequest(core.Gs2Request):
         return {
             "name": self.name,
             "description": self.description,
+            "transactionSetting": self.transaction_setting.to_dict() if self.transaction_setting else None,
             "firebaseSecret": self.firebase_secret,
             "logSetting": self.log_setting.to_dict() if self.log_setting else None,
         }
@@ -194,6 +208,7 @@ class UpdateNamespaceRequest(core.Gs2Request):
     context_stack: str = None
     namespace_name: str = None
     description: str = None
+    transaction_setting: TransactionSetting = None
     firebase_secret: str = None
     log_setting: LogSetting = None
 
@@ -205,6 +220,10 @@ class UpdateNamespaceRequest(core.Gs2Request):
         self.description = description
         return self
 
+    def with_transaction_setting(self, transaction_setting: TransactionSetting) -> UpdateNamespaceRequest:
+        self.transaction_setting = transaction_setting
+        return self
+
     def with_firebase_secret(self, firebase_secret: str) -> UpdateNamespaceRequest:
         self.firebase_secret = firebase_secret
         return self
@@ -234,6 +253,7 @@ class UpdateNamespaceRequest(core.Gs2Request):
         return UpdateNamespaceRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_description(data.get('description'))\
+            .with_transaction_setting(TransactionSetting.from_dict(data.get('transactionSetting')))\
             .with_firebase_secret(data.get('firebaseSecret'))\
             .with_log_setting(LogSetting.from_dict(data.get('logSetting')))
 
@@ -241,6 +261,7 @@ class UpdateNamespaceRequest(core.Gs2Request):
         return {
             "namespaceName": self.namespace_name,
             "description": self.description,
+            "transactionSetting": self.transaction_setting.to_dict() if self.transaction_setting else None,
             "firebaseSecret": self.firebase_secret,
             "logSetting": self.log_setting.to_dict() if self.log_setting else None,
         }
@@ -753,6 +774,8 @@ class SetUserIdRequest(core.Gs2Request):
     namespace_name: str = None
     access_token: str = None
     allow_concurrent_access: bool = None
+    session_id: str = None
+    force: bool = None
     duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> SetUserIdRequest:
@@ -767,6 +790,14 @@ class SetUserIdRequest(core.Gs2Request):
         self.allow_concurrent_access = allow_concurrent_access
         return self
 
+    def with_session_id(self, session_id: str) -> SetUserIdRequest:
+        self.session_id = session_id
+        return self
+
+    def with_force(self, force: bool) -> SetUserIdRequest:
+        self.force = force
+        return self
+
     def with_duplication_avoider(self, duplication_avoider: str) -> SetUserIdRequest:
         self.duplication_avoider = duplication_avoider
         return self
@@ -792,13 +823,17 @@ class SetUserIdRequest(core.Gs2Request):
         return SetUserIdRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_access_token(data.get('accessToken'))\
-            .with_allow_concurrent_access(data.get('allowConcurrentAccess'))
+            .with_allow_concurrent_access(data.get('allowConcurrentAccess'))\
+            .with_session_id(data.get('sessionId'))\
+            .with_force(data.get('force'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
             "accessToken": self.access_token,
             "allowConcurrentAccess": self.allow_concurrent_access,
+            "sessionId": self.session_id,
+            "force": self.force,
         }
 
 
@@ -808,6 +843,8 @@ class SetUserIdByUserIdRequest(core.Gs2Request):
     namespace_name: str = None
     user_id: str = None
     allow_concurrent_access: bool = None
+    session_id: str = None
+    force: bool = None
     time_offset_token: str = None
     duplication_avoider: str = None
 
@@ -823,6 +860,14 @@ class SetUserIdByUserIdRequest(core.Gs2Request):
         self.allow_concurrent_access = allow_concurrent_access
         return self
 
+    def with_session_id(self, session_id: str) -> SetUserIdByUserIdRequest:
+        self.session_id = session_id
+        return self
+
+    def with_force(self, force: bool) -> SetUserIdByUserIdRequest:
+        self.force = force
+        return self
+
     def with_time_offset_token(self, time_offset_token: str) -> SetUserIdByUserIdRequest:
         self.time_offset_token = time_offset_token
         return self
@@ -853,6 +898,8 @@ class SetUserIdByUserIdRequest(core.Gs2Request):
             .with_namespace_name(data.get('namespaceName'))\
             .with_user_id(data.get('userId'))\
             .with_allow_concurrent_access(data.get('allowConcurrentAccess'))\
+            .with_session_id(data.get('sessionId'))\
+            .with_force(data.get('force'))\
             .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
@@ -860,6 +907,8 @@ class SetUserIdByUserIdRequest(core.Gs2Request):
             "namespaceName": self.namespace_name,
             "userId": self.user_id,
             "allowConcurrentAccess": self.allow_concurrent_access,
+            "sessionId": self.session_id,
+            "force": self.force,
             "timeOffsetToken": self.time_offset_token,
         }
 
