@@ -37,6 +37,8 @@ class Gs2GatewayRestClient(rest.AbstractGs2RestClient):
         query_strings = {
             'contextStack': request.context_stack,
         }
+        if request.name_prefix is not None:
+            query_strings["namePrefix"] = request.name_prefix
         if request.page_token is not None:
             query_strings["pageToken"] = request.page_token
         if request.limit is not None:
@@ -115,6 +117,8 @@ class Gs2GatewayRestClient(rest.AbstractGs2RestClient):
             body["name"] = request.name
         if request.description is not None:
             body["description"] = request.description
+        if request.transaction_setting is not None:
+            body["transactionSetting"] = request.transaction_setting.to_dict()
         if request.firebase_secret is not None:
             body["firebaseSecret"] = request.firebase_secret
         if request.log_setting is not None:
@@ -337,6 +341,8 @@ class Gs2GatewayRestClient(rest.AbstractGs2RestClient):
         }
         if request.description is not None:
             body["description"] = request.description
+        if request.transaction_setting is not None:
+            body["transactionSetting"] = request.transaction_setting.to_dict()
         if request.firebase_secret is not None:
             body["firebaseSecret"] = request.firebase_secret
         if request.log_setting is not None:
@@ -1235,6 +1241,10 @@ class Gs2GatewayRestClient(rest.AbstractGs2RestClient):
         }
         if request.allow_concurrent_access is not None:
             body["allowConcurrentAccess"] = request.allow_concurrent_access
+        if request.session_id is not None:
+            body["sessionId"] = request.session_id
+        if request.force is not None:
+            body["force"] = request.force
 
         if request.request_id:
             headers["X-GS2-REQUEST-ID"] = request.request_id
@@ -1314,6 +1324,10 @@ class Gs2GatewayRestClient(rest.AbstractGs2RestClient):
         }
         if request.allow_concurrent_access is not None:
             body["allowConcurrentAccess"] = request.allow_concurrent_access
+        if request.session_id is not None:
+            body["sessionId"] = request.session_id
+        if request.force is not None:
+            body["force"] = request.force
 
         if request.request_id:
             headers["X-GS2-REQUEST-ID"] = request.request_id
