@@ -39,6 +39,8 @@ class Gs2GatewayWebSocketClient(web_socket.AbstractGs2WebSocketClient):
 
         if request.context_stack:
             body['contextStack'] = str(request.context_stack)
+        if request.name_prefix is not None:
+            body["namePrefix"] = request.name_prefix
         if request.page_token is not None:
             body["pageToken"] = request.page_token
         if request.limit is not None:
@@ -116,6 +118,8 @@ class Gs2GatewayWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["name"] = request.name
         if request.description is not None:
             body["description"] = request.description
+        if request.transaction_setting is not None:
+            body["transactionSetting"] = request.transaction_setting.to_dict()
         if request.firebase_secret is not None:
             body["firebaseSecret"] = request.firebase_secret
         if request.log_setting is not None:
@@ -335,6 +339,8 @@ class Gs2GatewayWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["namespaceName"] = request.namespace_name
         if request.description is not None:
             body["description"] = request.description
+        if request.transaction_setting is not None:
+            body["transactionSetting"] = request.transaction_setting.to_dict()
         if request.firebase_secret is not None:
             body["firebaseSecret"] = request.firebase_secret
         if request.log_setting is not None:
@@ -1227,6 +1233,10 @@ class Gs2GatewayWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["accessToken"] = request.access_token
         if request.allow_concurrent_access is not None:
             body["allowConcurrentAccess"] = request.allow_concurrent_access
+        if request.session_id is not None:
+            body["sessionId"] = request.session_id
+        if request.force is not None:
+            body["force"] = request.force
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -1306,6 +1316,10 @@ class Gs2GatewayWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["userId"] = request.user_id
         if request.allow_concurrent_access is not None:
             body["allowConcurrentAccess"] = request.allow_concurrent_access
+        if request.session_id is not None:
+            body["sessionId"] = request.session_id
+        if request.force is not None:
+            body["force"] = request.force
         if request.time_offset_token is not None:
             body["timeOffsetToken"] = request.time_offset_token
 
