@@ -1235,6 +1235,11 @@ class DeleteStatusByUserIdResult(core.Gs2Result):
 
 
 class VerifyGradeResult(core.Gs2Result):
+    item: Status = None
+
+    def with_item(self, item: Status) -> VerifyGradeResult:
+        self.item = item
+        return self
 
     def get(self, key, default=None):
         items = self.to_dict()
@@ -1255,13 +1260,20 @@ class VerifyGradeResult(core.Gs2Result):
         if data is None:
             return None
         return VerifyGradeResult()\
+            .with_item(Status.from_dict(data.get('item')))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
+            "item": self.item.to_dict() if self.item else None,
         }
 
 
 class VerifyGradeByUserIdResult(core.Gs2Result):
+    item: Status = None
+
+    def with_item(self, item: Status) -> VerifyGradeByUserIdResult:
+        self.item = item
+        return self
 
     def get(self, key, default=None):
         items = self.to_dict()
@@ -1282,9 +1294,11 @@ class VerifyGradeByUserIdResult(core.Gs2Result):
         if data is None:
             return None
         return VerifyGradeByUserIdResult()\
+            .with_item(Status.from_dict(data.get('item')))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
+            "item": self.item.to_dict() if self.item else None,
         }
 
 
@@ -1672,8 +1686,13 @@ class MultiplyAcquireActionsByStampSheetResult(core.Gs2Result):
 
 
 class VerifyGradeByStampTaskResult(core.Gs2Result):
+    item: Status = None
     new_context_stack: str = None
 
+    def with_item(self, item: Status) -> VerifyGradeByStampTaskResult:
+        self.item = item
+        return self
+
     def with_new_context_stack(self, new_context_stack: str) -> VerifyGradeByStampTaskResult:
         self.new_context_stack = new_context_stack
         return self
@@ -1697,10 +1716,12 @@ class VerifyGradeByStampTaskResult(core.Gs2Result):
         if data is None:
             return None
         return VerifyGradeByStampTaskResult()\
+            .with_item(Status.from_dict(data.get('item')))\
             .with_new_context_stack(data.get('newContextStack'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
+            "item": self.item.to_dict() if self.item else None,
             "newContextStack": self.new_context_stack,
         }
 
