@@ -188,6 +188,7 @@ class NotificationSetting(core.Gs2Model):
     gateway_namespace_id: str = None
     enable_transfer_mobile_notification: bool = None
     sound: str = None
+    enable: str = None
 
     def with_gateway_namespace_id(self, gateway_namespace_id: str) -> NotificationSetting:
         self.gateway_namespace_id = gateway_namespace_id
@@ -201,6 +202,10 @@ class NotificationSetting(core.Gs2Model):
         self.sound = sound
         return self
 
+    def with_enable(self, enable: str) -> NotificationSetting:
+        self.enable = enable
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -222,13 +227,15 @@ class NotificationSetting(core.Gs2Model):
         return NotificationSetting()\
             .with_gateway_namespace_id(data.get('gatewayNamespaceId'))\
             .with_enable_transfer_mobile_notification(data.get('enableTransferMobileNotification'))\
-            .with_sound(data.get('sound'))
+            .with_sound(data.get('sound'))\
+            .with_enable(data.get('enable'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "gatewayNamespaceId": self.gateway_namespace_id,
             "enableTransferMobileNotification": self.enable_transfer_mobile_notification,
             "sound": self.sound,
+            "enable": self.enable,
         }
 
 
@@ -236,6 +243,7 @@ class TransactionSetting(core.Gs2Model):
     enable_auto_run: bool = None
     enable_atomic_commit: bool = None
     transaction_use_distributor: bool = None
+    commit_script_result_in_use_distributor: bool = None
     acquire_action_use_job_queue: bool = None
     distributor_namespace_id: str = None
     key_id: str = None
@@ -253,6 +261,10 @@ class TransactionSetting(core.Gs2Model):
         self.transaction_use_distributor = transaction_use_distributor
         return self
 
+    def with_commit_script_result_in_use_distributor(self, commit_script_result_in_use_distributor: bool) -> TransactionSetting:
+        self.commit_script_result_in_use_distributor = commit_script_result_in_use_distributor
+        return self
+
     def with_acquire_action_use_job_queue(self, acquire_action_use_job_queue: bool) -> TransactionSetting:
         self.acquire_action_use_job_queue = acquire_action_use_job_queue
         return self
@@ -291,6 +303,7 @@ class TransactionSetting(core.Gs2Model):
             .with_enable_auto_run(data.get('enableAutoRun'))\
             .with_enable_atomic_commit(data.get('enableAtomicCommit'))\
             .with_transaction_use_distributor(data.get('transactionUseDistributor'))\
+            .with_commit_script_result_in_use_distributor(data.get('commitScriptResultInUseDistributor'))\
             .with_acquire_action_use_job_queue(data.get('acquireActionUseJobQueue'))\
             .with_distributor_namespace_id(data.get('distributorNamespaceId'))\
             .with_key_id(data.get('keyId'))\
@@ -301,6 +314,7 @@ class TransactionSetting(core.Gs2Model):
             "enableAutoRun": self.enable_auto_run,
             "enableAtomicCommit": self.enable_atomic_commit,
             "transactionUseDistributor": self.transaction_use_distributor,
+            "commitScriptResultInUseDistributor": self.commit_script_result_in_use_distributor,
             "acquireActionUseJobQueue": self.acquire_action_use_job_queue,
             "distributorNamespaceId": self.distributor_namespace_id,
             "keyId": self.key_id,
@@ -420,6 +434,7 @@ class SendMemberRequest(core.Gs2Model):
     user_id: str = None
     target_guild_name: str = None
     metadata: str = None
+    created_at: int = None
 
     def with_user_id(self, user_id: str) -> SendMemberRequest:
         self.user_id = user_id
@@ -433,6 +448,10 @@ class SendMemberRequest(core.Gs2Model):
         self.metadata = metadata
         return self
 
+    def with_created_at(self, created_at: int) -> SendMemberRequest:
+        self.created_at = created_at
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -461,13 +480,15 @@ class SendMemberRequest(core.Gs2Model):
         return SendMemberRequest()\
             .with_user_id(data.get('userId'))\
             .with_target_guild_name(data.get('targetGuildName'))\
-            .with_metadata(data.get('metadata'))
+            .with_metadata(data.get('metadata'))\
+            .with_created_at(data.get('createdAt'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "userId": self.user_id,
             "targetGuildName": self.target_guild_name,
             "metadata": self.metadata,
+            "createdAt": self.created_at,
         }
 
 
@@ -475,6 +496,7 @@ class ReceiveMemberRequest(core.Gs2Model):
     user_id: str = None
     target_guild_name: str = None
     metadata: str = None
+    created_at: int = None
 
     def with_user_id(self, user_id: str) -> ReceiveMemberRequest:
         self.user_id = user_id
@@ -488,6 +510,10 @@ class ReceiveMemberRequest(core.Gs2Model):
         self.metadata = metadata
         return self
 
+    def with_created_at(self, created_at: int) -> ReceiveMemberRequest:
+        self.created_at = created_at
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -516,13 +542,15 @@ class ReceiveMemberRequest(core.Gs2Model):
         return ReceiveMemberRequest()\
             .with_user_id(data.get('userId'))\
             .with_target_guild_name(data.get('targetGuildName'))\
-            .with_metadata(data.get('metadata'))
+            .with_metadata(data.get('metadata'))\
+            .with_created_at(data.get('createdAt'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "userId": self.user_id,
             "targetGuildName": self.target_guild_name,
             "metadata": self.metadata,
+            "createdAt": self.created_at,
         }
 
 
@@ -1194,310 +1222,6 @@ class Guild(core.Gs2Model):
         }
 
 
-class SendBox(core.Gs2Model):
-    send_box_id: str = None
-    user_id: str = None
-    guild_model_name: str = None
-    target_guild_names: List[str] = None
-    created_at: int = None
-    updated_at: int = None
-    revision: int = None
-
-    def with_send_box_id(self, send_box_id: str) -> SendBox:
-        self.send_box_id = send_box_id
-        return self
-
-    def with_user_id(self, user_id: str) -> SendBox:
-        self.user_id = user_id
-        return self
-
-    def with_guild_model_name(self, guild_model_name: str) -> SendBox:
-        self.guild_model_name = guild_model_name
-        return self
-
-    def with_target_guild_names(self, target_guild_names: List[str]) -> SendBox:
-        self.target_guild_names = target_guild_names
-        return self
-
-    def with_created_at(self, created_at: int) -> SendBox:
-        self.created_at = created_at
-        return self
-
-    def with_updated_at(self, updated_at: int) -> SendBox:
-        self.updated_at = updated_at
-        return self
-
-    def with_revision(self, revision: int) -> SendBox:
-        self.revision = revision
-        return self
-
-    @classmethod
-    def create_grn(
-        cls,
-        region,
-        owner_id,
-        namespace_name,
-        user_id,
-        guild_model_name,
-    ):
-        return 'grn:gs2:{region}:{ownerId}:guild:{namespaceName}:user:{userId}:sendBox:{guildModelName}'.format(
-            region=region,
-            ownerId=owner_id,
-            namespaceName=namespace_name,
-            userId=user_id,
-            guildModelName=guild_model_name,
-        )
-
-    @classmethod
-    def get_region_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):guild:(?P<namespaceName>.+):user:(?P<userId>.+):sendBox:(?P<guildModelName>.+)', grn)
-        if match is None:
-            return None
-        return match.group('region')
-
-    @classmethod
-    def get_owner_id_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):guild:(?P<namespaceName>.+):user:(?P<userId>.+):sendBox:(?P<guildModelName>.+)', grn)
-        if match is None:
-            return None
-        return match.group('owner_id')
-
-    @classmethod
-    def get_namespace_name_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):guild:(?P<namespaceName>.+):user:(?P<userId>.+):sendBox:(?P<guildModelName>.+)', grn)
-        if match is None:
-            return None
-        return match.group('namespace_name')
-
-    @classmethod
-    def get_user_id_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):guild:(?P<namespaceName>.+):user:(?P<userId>.+):sendBox:(?P<guildModelName>.+)', grn)
-        if match is None:
-            return None
-        return match.group('user_id')
-
-    @classmethod
-    def get_guild_model_name_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):guild:(?P<namespaceName>.+):user:(?P<userId>.+):sendBox:(?P<guildModelName>.+)', grn)
-        if match is None:
-            return None
-        return match.group('guild_model_name')
-
-    def get(self, key, default=None):
-        items = self.to_dict()
-        if key in items.keys():
-            return items[key]
-        return default
-
-    def __getitem__(self, key):
-        items = self.to_dict()
-        if key in items.keys():
-            return items[key]
-        return None
-
-    @staticmethod
-    def from_dict(
-        data: Dict[str, Any],
-    ) -> Optional[SendBox]:
-        if data is None:
-            return None
-        return SendBox()\
-            .with_send_box_id(data.get('sendBoxId'))\
-            .with_user_id(data.get('userId'))\
-            .with_guild_model_name(data.get('guildModelName'))\
-            .with_target_guild_names(None if data.get('targetGuildNames') is None else [
-                data.get('targetGuildNames')[i]
-                for i in range(len(data.get('targetGuildNames')))
-            ])\
-            .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))\
-            .with_revision(data.get('revision'))
-
-    def to_dict(self) -> Dict[str, Any]:
-        return {
-            "sendBoxId": self.send_box_id,
-            "userId": self.user_id,
-            "guildModelName": self.guild_model_name,
-            "targetGuildNames": None if self.target_guild_names is None else [
-                self.target_guild_names[i]
-                for i in range(len(self.target_guild_names))
-            ],
-            "createdAt": self.created_at,
-            "updatedAt": self.updated_at,
-            "revision": self.revision,
-        }
-
-
-class Inbox(core.Gs2Model):
-    inbox_id: str = None
-    guild_name: str = None
-    from_user_ids: List[str] = None
-    receive_member_requests: List[ReceiveMemberRequest] = None
-    created_at: int = None
-    updated_at: int = None
-    revision: int = None
-
-    def with_inbox_id(self, inbox_id: str) -> Inbox:
-        self.inbox_id = inbox_id
-        return self
-
-    def with_guild_name(self, guild_name: str) -> Inbox:
-        self.guild_name = guild_name
-        return self
-
-    def with_from_user_ids(self, from_user_ids: List[str]) -> Inbox:
-        self.from_user_ids = from_user_ids
-        return self
-
-    def with_receive_member_requests(self, receive_member_requests: List[ReceiveMemberRequest]) -> Inbox:
-        self.receive_member_requests = receive_member_requests
-        return self
-
-    def with_created_at(self, created_at: int) -> Inbox:
-        self.created_at = created_at
-        return self
-
-    def with_updated_at(self, updated_at: int) -> Inbox:
-        self.updated_at = updated_at
-        return self
-
-    def with_revision(self, revision: int) -> Inbox:
-        self.revision = revision
-        return self
-
-    @classmethod
-    def create_grn(
-        cls,
-        region,
-        owner_id,
-        namespace_name,
-        guild_model_name,
-        guild_name,
-    ):
-        return 'grn:gs2:{region}:{ownerId}:guild:{namespaceName}:guild:{guildModelName}:{guildName}:inbox'.format(
-            region=region,
-            ownerId=owner_id,
-            namespaceName=namespace_name,
-            guildModelName=guild_model_name,
-            guildName=guild_name,
-        )
-
-    @classmethod
-    def get_region_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):guild:(?P<namespaceName>.+):guild:(?P<guildModelName>.+):(?P<guildName>.+):inbox', grn)
-        if match is None:
-            return None
-        return match.group('region')
-
-    @classmethod
-    def get_owner_id_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):guild:(?P<namespaceName>.+):guild:(?P<guildModelName>.+):(?P<guildName>.+):inbox', grn)
-        if match is None:
-            return None
-        return match.group('owner_id')
-
-    @classmethod
-    def get_namespace_name_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):guild:(?P<namespaceName>.+):guild:(?P<guildModelName>.+):(?P<guildName>.+):inbox', grn)
-        if match is None:
-            return None
-        return match.group('namespace_name')
-
-    @classmethod
-    def get_guild_model_name_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):guild:(?P<namespaceName>.+):guild:(?P<guildModelName>.+):(?P<guildName>.+):inbox', grn)
-        if match is None:
-            return None
-        return match.group('guild_model_name')
-
-    @classmethod
-    def get_guild_name_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):guild:(?P<namespaceName>.+):guild:(?P<guildModelName>.+):(?P<guildName>.+):inbox', grn)
-        if match is None:
-            return None
-        return match.group('guild_name')
-
-    def get(self, key, default=None):
-        items = self.to_dict()
-        if key in items.keys():
-            return items[key]
-        return default
-
-    def __getitem__(self, key):
-        items = self.to_dict()
-        if key in items.keys():
-            return items[key]
-        return None
-
-    @staticmethod
-    def from_dict(
-        data: Dict[str, Any],
-    ) -> Optional[Inbox]:
-        if data is None:
-            return None
-        return Inbox()\
-            .with_inbox_id(data.get('inboxId'))\
-            .with_guild_name(data.get('guildName'))\
-            .with_from_user_ids(None if data.get('fromUserIds') is None else [
-                data.get('fromUserIds')[i]
-                for i in range(len(data.get('fromUserIds')))
-            ])\
-            .with_receive_member_requests(None if data.get('receiveMemberRequests') is None else [
-                ReceiveMemberRequest.from_dict(data.get('receiveMemberRequests')[i])
-                for i in range(len(data.get('receiveMemberRequests')))
-            ])\
-            .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))\
-            .with_revision(data.get('revision'))
-
-    def to_dict(self) -> Dict[str, Any]:
-        return {
-            "inboxId": self.inbox_id,
-            "guildName": self.guild_name,
-            "fromUserIds": None if self.from_user_ids is None else [
-                self.from_user_ids[i]
-                for i in range(len(self.from_user_ids))
-            ],
-            "receiveMemberRequests": None if self.receive_member_requests is None else [
-                self.receive_member_requests[i].to_dict() if self.receive_member_requests[i] else None
-                for i in range(len(self.receive_member_requests))
-            ],
-            "createdAt": self.created_at,
-            "updatedAt": self.updated_at,
-            "revision": self.revision,
-        }
-
-
 class GuildModel(core.Gs2Model):
     guild_model_id: str = None
     name: str = None
@@ -1874,15 +1598,18 @@ class Namespace(core.Gs2Model):
     namespace_id: str = None
     name: str = None
     description: str = None
+    transaction_setting: TransactionSetting = None
     change_notification: NotificationSetting = None
     join_notification: NotificationSetting = None
     leave_notification: NotificationSetting = None
     change_member_notification: NotificationSetting = None
+    change_member_notification_ignore_change_metadata: bool = None
     receive_request_notification: NotificationSetting = None
     remove_request_notification: NotificationSetting = None
     create_guild_script: ScriptSetting = None
     update_guild_script: ScriptSetting = None
     join_guild_script: ScriptSetting = None
+    receive_join_request_script: ScriptSetting = None
     leave_guild_script: ScriptSetting = None
     change_role_script: ScriptSetting = None
     delete_guild_script: ScriptSetting = None
@@ -1903,6 +1630,10 @@ class Namespace(core.Gs2Model):
         self.description = description
         return self
 
+    def with_transaction_setting(self, transaction_setting: TransactionSetting) -> Namespace:
+        self.transaction_setting = transaction_setting
+        return self
+
     def with_change_notification(self, change_notification: NotificationSetting) -> Namespace:
         self.change_notification = change_notification
         return self
@@ -1919,6 +1650,10 @@ class Namespace(core.Gs2Model):
         self.change_member_notification = change_member_notification
         return self
 
+    def with_change_member_notification_ignore_change_metadata(self, change_member_notification_ignore_change_metadata: bool) -> Namespace:
+        self.change_member_notification_ignore_change_metadata = change_member_notification_ignore_change_metadata
+        return self
+
     def with_receive_request_notification(self, receive_request_notification: NotificationSetting) -> Namespace:
         self.receive_request_notification = receive_request_notification
         return self
@@ -1939,6 +1674,10 @@ class Namespace(core.Gs2Model):
         self.join_guild_script = join_guild_script
         return self
 
+    def with_receive_join_request_script(self, receive_join_request_script: ScriptSetting) -> Namespace:
+        self.receive_join_request_script = receive_join_request_script
+        return self
+
     def with_leave_guild_script(self, leave_guild_script: ScriptSetting) -> Namespace:
         self.leave_guild_script = leave_guild_script
         return self
@@ -2032,15 +1771,18 @@ class Namespace(core.Gs2Model):
             .with_namespace_id(data.get('namespaceId'))\
             .with_name(data.get('name'))\
             .with_description(data.get('description'))\
+            .with_transaction_setting(TransactionSetting.from_dict(data.get('transactionSetting')))\
             .with_change_notification(NotificationSetting.from_dict(data.get('changeNotification')))\
             .with_join_notification(NotificationSetting.from_dict(data.get('joinNotification')))\
             .with_leave_notification(NotificationSetting.from_dict(data.get('leaveNotification')))\
             .with_change_member_notification(NotificationSetting.from_dict(data.get('changeMemberNotification')))\
+            .with_change_member_notification_ignore_change_metadata(data.get('changeMemberNotificationIgnoreChangeMetadata'))\
             .with_receive_request_notification(NotificationSetting.from_dict(data.get('receiveRequestNotification')))\
             .with_remove_request_notification(NotificationSetting.from_dict(data.get('removeRequestNotification')))\
             .with_create_guild_script(ScriptSetting.from_dict(data.get('createGuildScript')))\
             .with_update_guild_script(ScriptSetting.from_dict(data.get('updateGuildScript')))\
             .with_join_guild_script(ScriptSetting.from_dict(data.get('joinGuildScript')))\
+            .with_receive_join_request_script(ScriptSetting.from_dict(data.get('receiveJoinRequestScript')))\
             .with_leave_guild_script(ScriptSetting.from_dict(data.get('leaveGuildScript')))\
             .with_change_role_script(ScriptSetting.from_dict(data.get('changeRoleScript')))\
             .with_delete_guild_script(ScriptSetting.from_dict(data.get('deleteGuildScript')))\
@@ -2054,15 +1796,18 @@ class Namespace(core.Gs2Model):
             "namespaceId": self.namespace_id,
             "name": self.name,
             "description": self.description,
+            "transactionSetting": self.transaction_setting.to_dict() if self.transaction_setting else None,
             "changeNotification": self.change_notification.to_dict() if self.change_notification else None,
             "joinNotification": self.join_notification.to_dict() if self.join_notification else None,
             "leaveNotification": self.leave_notification.to_dict() if self.leave_notification else None,
             "changeMemberNotification": self.change_member_notification.to_dict() if self.change_member_notification else None,
+            "changeMemberNotificationIgnoreChangeMetadata": self.change_member_notification_ignore_change_metadata,
             "receiveRequestNotification": self.receive_request_notification.to_dict() if self.receive_request_notification else None,
             "removeRequestNotification": self.remove_request_notification.to_dict() if self.remove_request_notification else None,
             "createGuildScript": self.create_guild_script.to_dict() if self.create_guild_script else None,
             "updateGuildScript": self.update_guild_script.to_dict() if self.update_guild_script else None,
             "joinGuildScript": self.join_guild_script.to_dict() if self.join_guild_script else None,
+            "receiveJoinRequestScript": self.receive_join_request_script.to_dict() if self.receive_join_request_script else None,
             "leaveGuildScript": self.leave_guild_script.to_dict() if self.leave_guild_script else None,
             "changeRoleScript": self.change_role_script.to_dict() if self.change_role_script else None,
             "deleteGuildScript": self.delete_guild_script.to_dict() if self.delete_guild_script else None,
