@@ -16,6 +16,7 @@
 
 from __future__ import annotations
 
+from ..core.model import *
 from .model import *
 
 
@@ -50,17 +51,17 @@ class DescribeUsersResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeUsersResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 User.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
         }
@@ -233,17 +234,17 @@ class DescribeSecurityPoliciesResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeSecurityPoliciesResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 SecurityPolicy.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
         }
@@ -280,17 +281,17 @@ class DescribeCommonSecurityPoliciesResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeCommonSecurityPoliciesResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 SecurityPolicy.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
         }
@@ -463,17 +464,17 @@ class DescribeIdentifiersResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeIdentifiersResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 Identifier.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
         }
@@ -588,18 +589,13 @@ class DeleteIdentifierResult(core.Gs2Result):
         }
 
 
-class DescribePasswordsResult(core.Gs2Result):
-    items: List[Password] = None
-    next_page_token: str = None
+class DescribeAttachedGuardsResult(core.Gs2Result):
+    items: List[str] = None
 
-    def with_items(self, items: List[Password]) -> DescribePasswordsResult:
+    def with_items(self, items: List[str]) -> DescribeAttachedGuardsResult:
         self.items = items
         return self
 
-    def with_next_page_token(self, next_page_token: str) -> DescribePasswordsResult:
-        self.next_page_token = next_page_token
-        return self
-
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -615,23 +611,135 @@ class DescribePasswordsResult(core.Gs2Result):
     @staticmethod
     def from_dict(
         data: Dict[str, Any],
-    ) -> Optional[DescribePasswordsResult]:
+    ) -> Optional[DescribeAttachedGuardsResult]:
         if data is None:
             return None
-        return DescribePasswordsResult()\
-            .with_items([
-                Password.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
-            ])\
-            .with_next_page_token(data.get('nextPageToken'))
+        return DescribeAttachedGuardsResult()\
+            .with_items(None if data.get('items') is None else [
+                data.get('items')[i]
+                for i in range(len(data.get('items')))
+            ])
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
-                self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+            "items": None if self.items is None else [
+                self.items[i]
+                for i in range(len(self.items))
             ],
-            "nextPageToken": self.next_page_token,
+        }
+
+
+class AttachGuardResult(core.Gs2Result):
+    items: List[str] = None
+
+    def with_items(self, items: List[str]) -> AttachGuardResult:
+        self.items = items
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[AttachGuardResult]:
+        if data is None:
+            return None
+        return AttachGuardResult()\
+            .with_items(None if data.get('items') is None else [
+                data.get('items')[i]
+                for i in range(len(data.get('items')))
+            ])
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "items": None if self.items is None else [
+                self.items[i]
+                for i in range(len(self.items))
+            ],
+        }
+
+
+class DetachGuardResult(core.Gs2Result):
+    items: List[str] = None
+
+    def with_items(self, items: List[str]) -> DetachGuardResult:
+        self.items = items
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[DetachGuardResult]:
+        if data is None:
+            return None
+        return DetachGuardResult()\
+            .with_items(None if data.get('items') is None else [
+                data.get('items')[i]
+                for i in range(len(data.get('items')))
+            ])
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "items": None if self.items is None else [
+                self.items[i]
+                for i in range(len(self.items))
+            ],
+        }
+
+
+class GetServiceVersionResult(core.Gs2Result):
+    status: str = None
+
+    def with_status(self, status: str) -> GetServiceVersionResult:
+        self.status = status
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[GetServiceVersionResult]:
+        if data is None:
+            return None
+        return GetServiceVersionResult()\
+            .with_status(data.get('status'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "status": self.status,
         }
 
 
@@ -703,6 +811,115 @@ class GetPasswordResult(core.Gs2Result):
         }
 
 
+class EnableMfaResult(core.Gs2Result):
+    item: Password = None
+    challenge_token: str = None
+
+    def with_item(self, item: Password) -> EnableMfaResult:
+        self.item = item
+        return self
+
+    def with_challenge_token(self, challenge_token: str) -> EnableMfaResult:
+        self.challenge_token = challenge_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[EnableMfaResult]:
+        if data is None:
+            return None
+        return EnableMfaResult()\
+            .with_item(Password.from_dict(data.get('item')))\
+            .with_challenge_token(data.get('challengeToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "item": self.item.to_dict() if self.item else None,
+            "challengeToken": self.challenge_token,
+        }
+
+
+class ChallengeMfaResult(core.Gs2Result):
+    item: Password = None
+
+    def with_item(self, item: Password) -> ChallengeMfaResult:
+        self.item = item
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[ChallengeMfaResult]:
+        if data is None:
+            return None
+        return ChallengeMfaResult()\
+            .with_item(Password.from_dict(data.get('item')))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "item": self.item.to_dict() if self.item else None,
+        }
+
+
+class DisableMfaResult(core.Gs2Result):
+    item: Password = None
+
+    def with_item(self, item: Password) -> DisableMfaResult:
+        self.item = item
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[DisableMfaResult]:
+        if data is None:
+            return None
+        return DisableMfaResult()\
+            .with_item(Password.from_dict(data.get('item')))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "item": self.item.to_dict() if self.item else None,
+        }
+
+
 class DeletePasswordResult(core.Gs2Result):
     item: Password = None
 
@@ -763,16 +980,16 @@ class GetHasSecurityPolicyResult(core.Gs2Result):
         if data is None:
             return None
         return GetHasSecurityPolicyResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 SecurityPolicy.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
         }
 
@@ -803,16 +1020,16 @@ class AttachSecurityPolicyResult(core.Gs2Result):
         if data is None:
             return None
         return AttachSecurityPolicyResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 SecurityPolicy.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
         }
 
@@ -843,16 +1060,16 @@ class DetachSecurityPolicyResult(core.Gs2Result):
         if data is None:
             return None
         return DetachSecurityPolicyResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 SecurityPolicy.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
         }
 
@@ -861,6 +1078,7 @@ class LoginResult(core.Gs2Result):
     access_token: str = None
     token_type: str = None
     expires_in: int = None
+    owner_id: str = None
 
     def with_access_token(self, access_token: str) -> LoginResult:
         self.access_token = access_token
@@ -874,6 +1092,10 @@ class LoginResult(core.Gs2Result):
         self.expires_in = expires_in
         return self
 
+    def with_owner_id(self, owner_id: str) -> LoginResult:
+        self.owner_id = owner_id
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -895,13 +1117,15 @@ class LoginResult(core.Gs2Result):
         return LoginResult()\
             .with_access_token(data.get('access_token'))\
             .with_token_type(data.get('token_type'))\
-            .with_expires_in(data.get('expires_in'))
+            .with_expires_in(data.get('expires_in'))\
+            .with_owner_id(data.get('owner_id'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "access_token": self.access_token,
             "token_type": self.token_type,
             "expires_in": self.expires_in,
+            "owner_id": self.owner_id,
         }
 
 
