@@ -20,9 +20,14 @@ from .model import *
 class DescribeNamespacesRequest(core.Gs2Request):
 
     context_stack: str = None
+    name_prefix: str = None
     page_token: str = None
     limit: int = None
 
+    def with_name_prefix(self, name_prefix: str) -> DescribeNamespacesRequest:
+        self.name_prefix = name_prefix
+        return self
+
     def with_page_token(self, page_token: str) -> DescribeNamespacesRequest:
         self.page_token = page_token
         return self
@@ -50,11 +55,13 @@ class DescribeNamespacesRequest(core.Gs2Request):
         if data is None:
             return None
         return DescribeNamespacesRequest()\
+            .with_name_prefix(data.get('namePrefix'))\
             .with_page_token(data.get('pageToken'))\
             .with_limit(data.get('limit'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
+            "namePrefix": self.name_prefix,
             "pageToken": self.page_token,
             "limit": self.limit,
         }
@@ -658,6 +665,7 @@ class DescribeCategoryModelMastersRequest(core.Gs2Request):
 
     context_stack: str = None
     namespace_name: str = None
+    name_prefix: str = None
     page_token: str = None
     limit: int = None
 
@@ -665,6 +673,10 @@ class DescribeCategoryModelMastersRequest(core.Gs2Request):
         self.namespace_name = namespace_name
         return self
 
+    def with_name_prefix(self, name_prefix: str) -> DescribeCategoryModelMastersRequest:
+        self.name_prefix = name_prefix
+        return self
+
     def with_page_token(self, page_token: str) -> DescribeCategoryModelMastersRequest:
         self.page_token = page_token
         return self
@@ -693,12 +705,14 @@ class DescribeCategoryModelMastersRequest(core.Gs2Request):
             return None
         return DescribeCategoryModelMastersRequest()\
             .with_namespace_name(data.get('namespaceName'))\
+            .with_name_prefix(data.get('namePrefix'))\
             .with_page_token(data.get('pageToken'))\
             .with_limit(data.get('limit'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
+            "namePrefix": self.name_prefix,
             "pageToken": self.page_token,
             "limit": self.limit,
         }
@@ -1313,7 +1327,6 @@ class PredictionRequest(core.Gs2Request):
     namespace_name: str = None
     access_token: str = None
     category_name: str = None
-    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> PredictionRequest:
         self.namespace_name = namespace_name
@@ -1327,10 +1340,6 @@ class PredictionRequest(core.Gs2Request):
         self.category_name = category_name
         return self
 
-    def with_duplication_avoider(self, duplication_avoider: str) -> PredictionRequest:
-        self.duplication_avoider = duplication_avoider
-        return self
-
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1369,7 +1378,6 @@ class PredictionByUserIdRequest(core.Gs2Request):
     user_id: str = None
     category_name: str = None
     time_offset_token: str = None
-    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> PredictionByUserIdRequest:
         self.namespace_name = namespace_name
@@ -1387,10 +1395,6 @@ class PredictionByUserIdRequest(core.Gs2Request):
         self.time_offset_token = time_offset_token
         return self
 
-    def with_duplication_avoider(self, duplication_avoider: str) -> PredictionByUserIdRequest:
-        self.duplication_avoider = duplication_avoider
-        return self
-
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
