@@ -39,6 +39,8 @@ class Gs2IdleWebSocketClient(web_socket.AbstractGs2WebSocketClient):
 
         if request.context_stack:
             body['contextStack'] = str(request.context_stack)
+        if request.name_prefix is not None:
+            body["namePrefix"] = request.name_prefix
         if request.page_token is not None:
             body["pageToken"] = request.page_token
         if request.limit is not None:
@@ -1073,6 +1075,8 @@ class Gs2IdleWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body['contextStack'] = str(request.context_stack)
         if request.namespace_name is not None:
             body["namespaceName"] = request.namespace_name
+        if request.name_prefix is not None:
+            body["namePrefix"] = request.name_prefix
         if request.page_token is not None:
             body["pageToken"] = request.page_token
         if request.limit is not None:
@@ -1943,8 +1947,6 @@ class Gs2IdleWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["xGs2RequestId"] = request.request_id
         if request.access_token:
             body["xGs2AccessToken"] = request.access_token
-        if request.duplication_avoider:
-            body["xGs2DuplicationAvoider"] = request.duplication_avoider
 
         self.session.send(
             web_socket.NetworkJob(
@@ -2022,8 +2024,6 @@ class Gs2IdleWebSocketClient(web_socket.AbstractGs2WebSocketClient):
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
-        if request.duplication_avoider:
-            body["xGs2DuplicationAvoider"] = request.duplication_avoider
 
         self.session.send(
             web_socket.NetworkJob(
