@@ -23,6 +23,7 @@ class TransactionSetting(core.Gs2Model):
     enable_auto_run: bool = None
     enable_atomic_commit: bool = None
     transaction_use_distributor: bool = None
+    commit_script_result_in_use_distributor: bool = None
     acquire_action_use_job_queue: bool = None
     distributor_namespace_id: str = None
     key_id: str = None
@@ -40,6 +41,10 @@ class TransactionSetting(core.Gs2Model):
         self.transaction_use_distributor = transaction_use_distributor
         return self
 
+    def with_commit_script_result_in_use_distributor(self, commit_script_result_in_use_distributor: bool) -> TransactionSetting:
+        self.commit_script_result_in_use_distributor = commit_script_result_in_use_distributor
+        return self
+
     def with_acquire_action_use_job_queue(self, acquire_action_use_job_queue: bool) -> TransactionSetting:
         self.acquire_action_use_job_queue = acquire_action_use_job_queue
         return self
@@ -78,6 +83,7 @@ class TransactionSetting(core.Gs2Model):
             .with_enable_auto_run(data.get('enableAutoRun'))\
             .with_enable_atomic_commit(data.get('enableAtomicCommit'))\
             .with_transaction_use_distributor(data.get('transactionUseDistributor'))\
+            .with_commit_script_result_in_use_distributor(data.get('commitScriptResultInUseDistributor'))\
             .with_acquire_action_use_job_queue(data.get('acquireActionUseJobQueue'))\
             .with_distributor_namespace_id(data.get('distributorNamespaceId'))\
             .with_key_id(data.get('keyId'))\
@@ -88,6 +94,7 @@ class TransactionSetting(core.Gs2Model):
             "enableAutoRun": self.enable_auto_run,
             "enableAtomicCommit": self.enable_atomic_commit,
             "transactionUseDistributor": self.transaction_use_distributor,
+            "commitScriptResultInUseDistributor": self.commit_script_result_in_use_distributor,
             "acquireActionUseJobQueue": self.acquire_action_use_job_queue,
             "distributorNamespaceId": self.distributor_namespace_id,
             "keyId": self.key_id,
@@ -209,6 +216,7 @@ class NotificationSetting(core.Gs2Model):
     gateway_namespace_id: str = None
     enable_transfer_mobile_notification: bool = None
     sound: str = None
+    enable: str = None
 
     def with_gateway_namespace_id(self, gateway_namespace_id: str) -> NotificationSetting:
         self.gateway_namespace_id = gateway_namespace_id
@@ -222,6 +230,10 @@ class NotificationSetting(core.Gs2Model):
         self.sound = sound
         return self
 
+    def with_enable(self, enable: str) -> NotificationSetting:
+        self.enable = enable
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -243,13 +255,15 @@ class NotificationSetting(core.Gs2Model):
         return NotificationSetting()\
             .with_gateway_namespace_id(data.get('gatewayNamespaceId'))\
             .with_enable_transfer_mobile_notification(data.get('enableTransferMobileNotification'))\
-            .with_sound(data.get('sound'))
+            .with_sound(data.get('sound'))\
+            .with_enable(data.get('enable'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "gatewayNamespaceId": self.gateway_namespace_id,
             "enableTransferMobileNotification": self.enable_transfer_mobile_notification,
             "sound": self.sound,
+            "enable": self.enable,
         }
 
 
