@@ -20,9 +20,14 @@ from .model import *
 class DescribeNamespacesRequest(core.Gs2Request):
 
     context_stack: str = None
+    name_prefix: str = None
     page_token: str = None
     limit: int = None
 
+    def with_name_prefix(self, name_prefix: str) -> DescribeNamespacesRequest:
+        self.name_prefix = name_prefix
+        return self
+
     def with_page_token(self, page_token: str) -> DescribeNamespacesRequest:
         self.page_token = page_token
         return self
@@ -50,11 +55,13 @@ class DescribeNamespacesRequest(core.Gs2Request):
         if data is None:
             return None
         return DescribeNamespacesRequest()\
+            .with_name_prefix(data.get('namePrefix'))\
             .with_page_token(data.get('pageToken'))\
             .with_limit(data.get('limit'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
+            "namePrefix": self.name_prefix,
             "pageToken": self.page_token,
             "limit": self.limit,
         }
@@ -65,6 +72,7 @@ class CreateNamespaceRequest(core.Gs2Request):
     context_stack: str = None
     name: str = None
     description: str = None
+    transaction_setting: TransactionSetting = None
     enable_auto_run: bool = None
     push_notification: NotificationSetting = None
     run_notification: NotificationSetting = None
@@ -78,6 +86,10 @@ class CreateNamespaceRequest(core.Gs2Request):
         self.description = description
         return self
 
+    def with_transaction_setting(self, transaction_setting: TransactionSetting) -> CreateNamespaceRequest:
+        self.transaction_setting = transaction_setting
+        return self
+
     def with_enable_auto_run(self, enable_auto_run: bool) -> CreateNamespaceRequest:
         self.enable_auto_run = enable_auto_run
         return self
@@ -115,6 +127,7 @@ class CreateNamespaceRequest(core.Gs2Request):
         return CreateNamespaceRequest()\
             .with_name(data.get('name'))\
             .with_description(data.get('description'))\
+            .with_transaction_setting(TransactionSetting.from_dict(data.get('transactionSetting')))\
             .with_enable_auto_run(data.get('enableAutoRun'))\
             .with_push_notification(NotificationSetting.from_dict(data.get('pushNotification')))\
             .with_run_notification(NotificationSetting.from_dict(data.get('runNotification')))\
@@ -124,6 +137,7 @@ class CreateNamespaceRequest(core.Gs2Request):
         return {
             "name": self.name,
             "description": self.description,
+            "transactionSetting": self.transaction_setting.to_dict() if self.transaction_setting else None,
             "enableAutoRun": self.enable_auto_run,
             "pushNotification": self.push_notification.to_dict() if self.push_notification else None,
             "runNotification": self.run_notification.to_dict() if self.run_notification else None,
@@ -208,6 +222,7 @@ class UpdateNamespaceRequest(core.Gs2Request):
     context_stack: str = None
     namespace_name: str = None
     description: str = None
+    transaction_setting: TransactionSetting = None
     enable_auto_run: bool = None
     push_notification: NotificationSetting = None
     run_notification: NotificationSetting = None
@@ -221,6 +236,10 @@ class UpdateNamespaceRequest(core.Gs2Request):
         self.description = description
         return self
 
+    def with_transaction_setting(self, transaction_setting: TransactionSetting) -> UpdateNamespaceRequest:
+        self.transaction_setting = transaction_setting
+        return self
+
     def with_enable_auto_run(self, enable_auto_run: bool) -> UpdateNamespaceRequest:
         self.enable_auto_run = enable_auto_run
         return self
@@ -258,6 +277,7 @@ class UpdateNamespaceRequest(core.Gs2Request):
         return UpdateNamespaceRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_description(data.get('description'))\
+            .with_transaction_setting(TransactionSetting.from_dict(data.get('transactionSetting')))\
             .with_enable_auto_run(data.get('enableAutoRun'))\
             .with_push_notification(NotificationSetting.from_dict(data.get('pushNotification')))\
             .with_run_notification(NotificationSetting.from_dict(data.get('runNotification')))\
@@ -267,6 +287,7 @@ class UpdateNamespaceRequest(core.Gs2Request):
         return {
             "namespaceName": self.namespace_name,
             "description": self.description,
+            "transactionSetting": self.transaction_setting.to_dict() if self.transaction_setting else None,
             "enableAutoRun": self.enable_auto_run,
             "pushNotification": self.push_notification.to_dict() if self.push_notification else None,
             "runNotification": self.run_notification.to_dict() if self.run_notification else None,
