@@ -785,6 +785,11 @@ class DeleteCounterByUserIdResult(core.Gs2Result):
 
 
 class VerifyCounterResult(core.Gs2Result):
+    item: Counter = None
+
+    def with_item(self, item: Counter) -> VerifyCounterResult:
+        self.item = item
+        return self
 
     def get(self, key, default=None):
         items = self.to_dict()
@@ -805,13 +810,20 @@ class VerifyCounterResult(core.Gs2Result):
         if data is None:
             return None
         return VerifyCounterResult()\
+            .with_item(Counter.from_dict(data.get('item')))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
+            "item": self.item.to_dict() if self.item else None,
         }
 
 
 class VerifyCounterByUserIdResult(core.Gs2Result):
+    item: Counter = None
+
+    def with_item(self, item: Counter) -> VerifyCounterByUserIdResult:
+        self.item = item
+        return self
 
     def get(self, key, default=None):
         items = self.to_dict()
@@ -832,9 +844,11 @@ class VerifyCounterByUserIdResult(core.Gs2Result):
         if data is None:
             return None
         return VerifyCounterByUserIdResult()\
+            .with_item(Counter.from_dict(data.get('item')))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
+            "item": self.item.to_dict() if self.item else None,
         }
 
 
@@ -948,8 +962,13 @@ class DeleteByStampSheetResult(core.Gs2Result):
 
 
 class VerifyCounterByStampTaskResult(core.Gs2Result):
+    item: Counter = None
     new_context_stack: str = None
 
+    def with_item(self, item: Counter) -> VerifyCounterByStampTaskResult:
+        self.item = item
+        return self
+
     def with_new_context_stack(self, new_context_stack: str) -> VerifyCounterByStampTaskResult:
         self.new_context_stack = new_context_stack
         return self
@@ -973,10 +992,12 @@ class VerifyCounterByStampTaskResult(core.Gs2Result):
         if data is None:
             return None
         return VerifyCounterByStampTaskResult()\
+            .with_item(Counter.from_dict(data.get('item')))\
             .with_new_context_stack(data.get('newContextStack'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
+            "item": self.item.to_dict() if self.item else None,
             "newContextStack": self.new_context_stack,
         }
 
