@@ -39,6 +39,8 @@ class Gs2LimitWebSocketClient(web_socket.AbstractGs2WebSocketClient):
 
         if request.context_stack:
             body['contextStack'] = str(request.context_stack)
+        if request.name_prefix is not None:
+            body["namePrefix"] = request.name_prefix
         if request.page_token is not None:
             body["pageToken"] = request.page_token
         if request.limit is not None:
@@ -116,6 +118,8 @@ class Gs2LimitWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["name"] = request.name
         if request.description is not None:
             body["description"] = request.description
+        if request.transaction_setting is not None:
+            body["transactionSetting"] = request.transaction_setting.to_dict()
         if request.log_setting is not None:
             body["logSetting"] = request.log_setting.to_dict()
 
@@ -333,6 +337,8 @@ class Gs2LimitWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["namespaceName"] = request.namespace_name
         if request.description is not None:
             body["description"] = request.description
+        if request.transaction_setting is not None:
+            body["transactionSetting"] = request.transaction_setting.to_dict()
         if request.log_setting is not None:
             body["logSetting"] = request.log_setting.to_dict()
 
@@ -2181,6 +2187,8 @@ class Gs2LimitWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body['contextStack'] = str(request.context_stack)
         if request.namespace_name is not None:
             body["namespaceName"] = request.namespace_name
+        if request.name_prefix is not None:
+            body["namePrefix"] = request.name_prefix
         if request.page_token is not None:
             body["pageToken"] = request.page_token
         if request.limit is not None:
