@@ -39,6 +39,8 @@ class Gs2LockWebSocketClient(web_socket.AbstractGs2WebSocketClient):
 
         if request.context_stack:
             body['contextStack'] = str(request.context_stack)
+        if request.name_prefix is not None:
+            body["namePrefix"] = request.name_prefix
         if request.page_token is not None:
             body["pageToken"] = request.page_token
         if request.limit is not None:
