@@ -19,6 +19,47 @@ from typing import *
 from gs2 import core
 
 
+class InGameLogTag(core.Gs2Model):
+    key: str = None
+    value: str = None
+
+    def with_key(self, key: str) -> InGameLogTag:
+        self.key = key
+        return self
+
+    def with_value(self, value: str) -> InGameLogTag:
+        self.value = value
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[InGameLogTag]:
+        if data is None:
+            return None
+        return InGameLogTag()\
+            .with_key(data.get('key'))\
+            .with_value(data.get('value'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "key": self.key,
+            "value": self.value,
+        }
+
+
 class Insight(core.Gs2Model):
     insight_id: str = None
     name: str = None
@@ -27,6 +68,7 @@ class Insight(core.Gs2Model):
     password: str = None
     status: str = None
     created_at: int = None
+    revision: int = None
 
     def with_insight_id(self, insight_id: str) -> Insight:
         self.insight_id = insight_id
@@ -56,6 +98,10 @@ class Insight(core.Gs2Model):
         self.created_at = created_at
         return self
 
+    def with_revision(self, revision: int) -> Insight:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -136,7 +182,8 @@ class Insight(core.Gs2Model):
             .with_host(data.get('host'))\
             .with_password(data.get('password'))\
             .with_status(data.get('status'))\
-            .with_created_at(data.get('createdAt'))
+            .with_created_at(data.get('createdAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -147,6 +194,179 @@ class Insight(core.Gs2Model):
             "password": self.password,
             "status": self.status,
             "createdAt": self.created_at,
+            "revision": self.revision,
+        }
+
+
+class AccessLogWithTelemetry(core.Gs2Model):
+    timestamp: int = None
+    source_request_id: str = None
+    request_id: str = None
+    duration: int = None
+    service: str = None
+    method: str = None
+    user_id: str = None
+    request: str = None
+    result: str = None
+    status: str = None
+
+    def with_timestamp(self, timestamp: int) -> AccessLogWithTelemetry:
+        self.timestamp = timestamp
+        return self
+
+    def with_source_request_id(self, source_request_id: str) -> AccessLogWithTelemetry:
+        self.source_request_id = source_request_id
+        return self
+
+    def with_request_id(self, request_id: str) -> AccessLogWithTelemetry:
+        self.request_id = request_id
+        return self
+
+    def with_duration(self, duration: int) -> AccessLogWithTelemetry:
+        self.duration = duration
+        return self
+
+    def with_service(self, service: str) -> AccessLogWithTelemetry:
+        self.service = service
+        return self
+
+    def with_method(self, method: str) -> AccessLogWithTelemetry:
+        self.method = method
+        return self
+
+    def with_user_id(self, user_id: str) -> AccessLogWithTelemetry:
+        self.user_id = user_id
+        return self
+
+    def with_request(self, request: str) -> AccessLogWithTelemetry:
+        self.request = request
+        return self
+
+    def with_result(self, result: str) -> AccessLogWithTelemetry:
+        self.result = result
+        return self
+
+    def with_status(self, status: str) -> AccessLogWithTelemetry:
+        self.status = status
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[AccessLogWithTelemetry]:
+        if data is None:
+            return None
+        return AccessLogWithTelemetry()\
+            .with_timestamp(data.get('timestamp'))\
+            .with_source_request_id(data.get('sourceRequestId'))\
+            .with_request_id(data.get('requestId'))\
+            .with_duration(data.get('duration'))\
+            .with_service(data.get('service'))\
+            .with_method(data.get('method'))\
+            .with_user_id(data.get('userId'))\
+            .with_request(data.get('request'))\
+            .with_result(data.get('result'))\
+            .with_status(data.get('status'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "timestamp": self.timestamp,
+            "sourceRequestId": self.source_request_id,
+            "requestId": self.request_id,
+            "duration": self.duration,
+            "service": self.service,
+            "method": self.method,
+            "userId": self.user_id,
+            "request": self.request,
+            "result": self.result,
+            "status": self.status,
+        }
+
+
+class InGameLog(core.Gs2Model):
+    timestamp: int = None
+    request_id: str = None
+    user_id: str = None
+    tags: List[InGameLogTag] = None
+    payload: str = None
+
+    def with_timestamp(self, timestamp: int) -> InGameLog:
+        self.timestamp = timestamp
+        return self
+
+    def with_request_id(self, request_id: str) -> InGameLog:
+        self.request_id = request_id
+        return self
+
+    def with_user_id(self, user_id: str) -> InGameLog:
+        self.user_id = user_id
+        return self
+
+    def with_tags(self, tags: List[InGameLogTag]) -> InGameLog:
+        self.tags = tags
+        return self
+
+    def with_payload(self, payload: str) -> InGameLog:
+        self.payload = payload
+        return self
+
+    @classmethod
+    def create_grn(
+        cls,
+    ):
+        return ''.format(
+        )
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[InGameLog]:
+        if data is None:
+            return None
+        return InGameLog()\
+            .with_timestamp(data.get('timestamp'))\
+            .with_request_id(data.get('requestId'))\
+            .with_user_id(data.get('userId'))\
+            .with_tags(None if data.get('tags') is None else [
+                InGameLogTag.from_dict(data.get('tags')[i])
+                for i in range(len(data.get('tags')))
+            ])\
+            .with_payload(data.get('payload'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "timestamp": self.timestamp,
+            "requestId": self.request_id,
+            "userId": self.user_id,
+            "tags": None if self.tags is None else [
+                self.tags[i].to_dict() if self.tags[i] else None
+                for i in range(len(self.tags))
+            ],
+            "payload": self.payload,
         }
 
 
@@ -556,9 +776,9 @@ class IssueStampSheetLog(core.Gs2Model):
             .with_user_id(data.get('userId'))\
             .with_action(data.get('action'))\
             .with_args(data.get('args'))\
-            .with_tasks([
+            .with_tasks(None if data.get('tasks') is None else [
                 data.get('tasks')[i]
-                for i in range(len(data.get('tasks')) if data.get('tasks') else 0)
+                for i in range(len(data.get('tasks')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
@@ -570,9 +790,9 @@ class IssueStampSheetLog(core.Gs2Model):
             "userId": self.user_id,
             "action": self.action,
             "args": self.args,
-            "tasks": [
+            "tasks": None if self.tasks is None else [
                 self.tasks[i]
-                for i in range(len(self.tasks) if self.tasks else 0)
+                for i in range(len(self.tasks))
             ],
         }
 
@@ -720,9 +940,11 @@ class Namespace(core.Gs2Model):
     aws_access_key_id: str = None
     aws_secret_access_key: str = None
     firehose_stream_name: str = None
+    firehose_compress_data: str = None
     status: str = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_namespace_id(self, namespace_id: str) -> Namespace:
         self.namespace_id = namespace_id
@@ -768,6 +990,10 @@ class Namespace(core.Gs2Model):
         self.firehose_stream_name = firehose_stream_name
         return self
 
+    def with_firehose_compress_data(self, firehose_compress_data: str) -> Namespace:
+        self.firehose_compress_data = firehose_compress_data
+        return self
+
     def with_status(self, status: str) -> Namespace:
         self.status = status
         return self
@@ -780,6 +1006,10 @@ class Namespace(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Namespace:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -853,9 +1083,11 @@ class Namespace(core.Gs2Model):
             .with_aws_access_key_id(data.get('awsAccessKeyId'))\
             .with_aws_secret_access_key(data.get('awsSecretAccessKey'))\
             .with_firehose_stream_name(data.get('firehoseStreamName'))\
+            .with_firehose_compress_data(data.get('firehoseCompressData'))\
             .with_status(data.get('status'))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -870,7 +1102,9 @@ class Namespace(core.Gs2Model):
             "awsAccessKeyId": self.aws_access_key_id,
             "awsSecretAccessKey": self.aws_secret_access_key,
             "firehoseStreamName": self.firehose_stream_name,
+            "firehoseCompressData": self.firehose_compress_data,
             "status": self.status,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
\ No newline at end of file
