@@ -14,6 +14,7 @@
 
 from __future__ import annotations
 
+from ..core.model import *
 from .model import *
 
 
@@ -48,17 +49,17 @@ class DescribeNamespacesResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeNamespacesResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 Namespace.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
         }
@@ -234,6 +235,40 @@ class DeleteNamespaceResult(core.Gs2Result):
         }
 
 
+class GetServiceVersionResult(core.Gs2Result):
+    item: str = None
+
+    def with_item(self, item: str) -> GetServiceVersionResult:
+        self.item = item
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[GetServiceVersionResult]:
+        if data is None:
+            return None
+        return GetServiceVersionResult()\
+            .with_item(data.get('item'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "item": self.item,
+        }
+
+
 class QueryAccessLogResult(core.Gs2Result):
     items: List[AccessLog] = None
     next_page_token: str = None
@@ -275,9 +310,9 @@ class QueryAccessLogResult(core.Gs2Result):
         if data is None:
             return None
         return QueryAccessLogResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 AccessLog.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))\
             .with_total_count(data.get('totalCount'))\
@@ -285,9 +320,9 @@ class QueryAccessLogResult(core.Gs2Result):
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
             "totalCount": self.total_count,
@@ -336,9 +371,9 @@ class CountAccessLogResult(core.Gs2Result):
         if data is None:
             return None
         return CountAccessLogResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 AccessLogCount.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))\
             .with_total_count(data.get('totalCount'))\
@@ -346,9 +381,9 @@ class CountAccessLogResult(core.Gs2Result):
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
             "totalCount": self.total_count,
@@ -397,9 +432,9 @@ class QueryIssueStampSheetLogResult(core.Gs2Result):
         if data is None:
             return None
         return QueryIssueStampSheetLogResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 IssueStampSheetLog.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))\
             .with_total_count(data.get('totalCount'))\
@@ -407,9 +442,9 @@ class QueryIssueStampSheetLogResult(core.Gs2Result):
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
             "totalCount": self.total_count,
@@ -458,9 +493,9 @@ class CountIssueStampSheetLogResult(core.Gs2Result):
         if data is None:
             return None
         return CountIssueStampSheetLogResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 IssueStampSheetLogCount.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))\
             .with_total_count(data.get('totalCount'))\
@@ -468,9 +503,9 @@ class CountIssueStampSheetLogResult(core.Gs2Result):
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
             "totalCount": self.total_count,
@@ -519,9 +554,9 @@ class QueryExecuteStampSheetLogResult(core.Gs2Result):
         if data is None:
             return None
         return QueryExecuteStampSheetLogResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 ExecuteStampSheetLog.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))\
             .with_total_count(data.get('totalCount'))\
@@ -529,9 +564,9 @@ class QueryExecuteStampSheetLogResult(core.Gs2Result):
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
             "totalCount": self.total_count,
@@ -580,9 +615,9 @@ class CountExecuteStampSheetLogResult(core.Gs2Result):
         if data is None:
             return None
         return CountExecuteStampSheetLogResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 ExecuteStampSheetLogCount.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))\
             .with_total_count(data.get('totalCount'))\
@@ -590,9 +625,9 @@ class CountExecuteStampSheetLogResult(core.Gs2Result):
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
             "totalCount": self.total_count,
@@ -641,9 +676,9 @@ class QueryExecuteStampTaskLogResult(core.Gs2Result):
         if data is None:
             return None
         return QueryExecuteStampTaskLogResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 ExecuteStampTaskLog.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))\
             .with_total_count(data.get('totalCount'))\
@@ -651,9 +686,9 @@ class QueryExecuteStampTaskLogResult(core.Gs2Result):
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
             "totalCount": self.total_count,
@@ -702,9 +737,9 @@ class CountExecuteStampTaskLogResult(core.Gs2Result):
         if data is None:
             return None
         return CountExecuteStampTaskLogResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 ExecuteStampTaskLogCount.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))\
             .with_total_count(data.get('totalCount'))\
@@ -712,9 +747,9 @@ class CountExecuteStampTaskLogResult(core.Gs2Result):
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
             "totalCount": self.total_count,
@@ -722,7 +757,27 @@ class CountExecuteStampTaskLogResult(core.Gs2Result):
         }
 
 
-class PutLogResult(core.Gs2Result):
+class QueryInGameLogResult(core.Gs2Result):
+    items: List[InGameLog] = None
+    next_page_token: str = None
+    total_count: int = None
+    scan_size: int = None
+
+    def with_items(self, items: List[InGameLog]) -> QueryInGameLogResult:
+        self.items = items
+        return self
+
+    def with_next_page_token(self, next_page_token: str) -> QueryInGameLogResult:
+        self.next_page_token = next_page_token
+        return self
+
+    def with_total_count(self, total_count: int) -> QueryInGameLogResult:
+        self.total_count = total_count
+        return self
+
+    def with_scan_size(self, scan_size: int) -> QueryInGameLogResult:
+        self.scan_size = scan_size
+        return self
 
     def get(self, key, default=None):
         items = self.to_dict()
@@ -739,13 +794,156 @@ class PutLogResult(core.Gs2Result):
     @staticmethod
     def from_dict(
         data: Dict[str, Any],
-    ) -> Optional[PutLogResult]:
+    ) -> Optional[QueryInGameLogResult]:
         if data is None:
             return None
-        return PutLogResult()\
+        return QueryInGameLogResult()\
+            .with_items(None if data.get('items') is None else [
+                InGameLog.from_dict(data.get('items')[i])
+                for i in range(len(data.get('items')))
+            ])\
+            .with_next_page_token(data.get('nextPageToken'))\
+            .with_total_count(data.get('totalCount'))\
+            .with_scan_size(data.get('scanSize'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
+            "items": None if self.items is None else [
+                self.items[i].to_dict() if self.items[i] else None
+                for i in range(len(self.items))
+            ],
+            "nextPageToken": self.next_page_token,
+            "totalCount": self.total_count,
+            "scanSize": self.scan_size,
+        }
+
+
+class SendInGameLogResult(core.Gs2Result):
+    item: InGameLog = None
+
+    def with_item(self, item: InGameLog) -> SendInGameLogResult:
+        self.item = item
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[SendInGameLogResult]:
+        if data is None:
+            return None
+        return SendInGameLogResult()\
+            .with_item(InGameLog.from_dict(data.get('item')))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "item": self.item.to_dict() if self.item else None,
+        }
+
+
+class SendInGameLogByUserIdResult(core.Gs2Result):
+    item: InGameLog = None
+
+    def with_item(self, item: InGameLog) -> SendInGameLogByUserIdResult:
+        self.item = item
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[SendInGameLogByUserIdResult]:
+        if data is None:
+            return None
+        return SendInGameLogByUserIdResult()\
+            .with_item(InGameLog.from_dict(data.get('item')))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "item": self.item.to_dict() if self.item else None,
+        }
+
+
+class QueryAccessLogWithTelemetryResult(core.Gs2Result):
+    items: List[AccessLogWithTelemetry] = None
+    next_page_token: str = None
+    total_count: int = None
+    scan_size: int = None
+
+    def with_items(self, items: List[AccessLogWithTelemetry]) -> QueryAccessLogWithTelemetryResult:
+        self.items = items
+        return self
+
+    def with_next_page_token(self, next_page_token: str) -> QueryAccessLogWithTelemetryResult:
+        self.next_page_token = next_page_token
+        return self
+
+    def with_total_count(self, total_count: int) -> QueryAccessLogWithTelemetryResult:
+        self.total_count = total_count
+        return self
+
+    def with_scan_size(self, scan_size: int) -> QueryAccessLogWithTelemetryResult:
+        self.scan_size = scan_size
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[QueryAccessLogWithTelemetryResult]:
+        if data is None:
+            return None
+        return QueryAccessLogWithTelemetryResult()\
+            .with_items(None if data.get('items') is None else [
+                AccessLogWithTelemetry.from_dict(data.get('items')[i])
+                for i in range(len(data.get('items')))
+            ])\
+            .with_next_page_token(data.get('nextPageToken'))\
+            .with_total_count(data.get('totalCount'))\
+            .with_scan_size(data.get('scanSize'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "items": None if self.items is None else [
+                self.items[i].to_dict() if self.items[i] else None
+                for i in range(len(self.items))
+            ],
+            "nextPageToken": self.next_page_token,
+            "totalCount": self.total_count,
+            "scanSize": self.scan_size,
         }
 
 
@@ -780,17 +978,17 @@ class DescribeInsightsResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeInsightsResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 Insight.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
         }
