@@ -23,6 +23,7 @@ class TransactionSetting(core.Gs2Model):
     enable_auto_run: bool = None
     enable_atomic_commit: bool = None
     transaction_use_distributor: bool = None
+    commit_script_result_in_use_distributor: bool = None
     acquire_action_use_job_queue: bool = None
     distributor_namespace_id: str = None
     key_id: str = None
@@ -40,6 +41,10 @@ class TransactionSetting(core.Gs2Model):
         self.transaction_use_distributor = transaction_use_distributor
         return self
 
+    def with_commit_script_result_in_use_distributor(self, commit_script_result_in_use_distributor: bool) -> TransactionSetting:
+        self.commit_script_result_in_use_distributor = commit_script_result_in_use_distributor
+        return self
+
     def with_acquire_action_use_job_queue(self, acquire_action_use_job_queue: bool) -> TransactionSetting:
         self.acquire_action_use_job_queue = acquire_action_use_job_queue
         return self
@@ -78,6 +83,7 @@ class TransactionSetting(core.Gs2Model):
             .with_enable_auto_run(data.get('enableAutoRun'))\
             .with_enable_atomic_commit(data.get('enableAtomicCommit'))\
             .with_transaction_use_distributor(data.get('transactionUseDistributor'))\
+            .with_commit_script_result_in_use_distributor(data.get('commitScriptResultInUseDistributor'))\
             .with_acquire_action_use_job_queue(data.get('acquireActionUseJobQueue'))\
             .with_distributor_namespace_id(data.get('distributorNamespaceId'))\
             .with_key_id(data.get('keyId'))\
@@ -88,6 +94,7 @@ class TransactionSetting(core.Gs2Model):
             "enableAutoRun": self.enable_auto_run,
             "enableAtomicCommit": self.enable_atomic_commit,
             "transactionUseDistributor": self.transaction_use_distributor,
+            "commitScriptResultInUseDistributor": self.commit_script_result_in_use_distributor,
             "acquireActionUseJobQueue": self.acquire_action_use_job_queue,
             "distributorNamespaceId": self.distributor_namespace_id,
             "keyId": self.key_id,
@@ -1422,7 +1429,6 @@ class Namespace(core.Gs2Model):
     description: str = None
     transaction_setting: TransactionSetting = None
     lottery_trigger_script_id: str = None
-    choice_prize_table_script_id: str = None
     log_setting: LogSetting = None
     created_at: int = None
     updated_at: int = None
@@ -1450,10 +1456,6 @@ class Namespace(core.Gs2Model):
         self.lottery_trigger_script_id = lottery_trigger_script_id
         return self
 
-    def with_choice_prize_table_script_id(self, choice_prize_table_script_id: str) -> Namespace:
-        self.choice_prize_table_script_id = choice_prize_table_script_id
-        return self
-
     def with_log_setting(self, log_setting: LogSetting) -> Namespace:
         self.log_setting = log_setting
         return self
@@ -1545,7 +1547,6 @@ class Namespace(core.Gs2Model):
             .with_description(data.get('description'))\
             .with_transaction_setting(TransactionSetting.from_dict(data.get('transactionSetting')))\
             .with_lottery_trigger_script_id(data.get('lotteryTriggerScriptId'))\
-            .with_choice_prize_table_script_id(data.get('choicePrizeTableScriptId'))\
             .with_log_setting(LogSetting.from_dict(data.get('logSetting')))\
             .with_created_at(data.get('createdAt'))\
             .with_updated_at(data.get('updatedAt'))\
@@ -1560,7 +1561,6 @@ class Namespace(core.Gs2Model):
             "description": self.description,
             "transactionSetting": self.transaction_setting.to_dict() if self.transaction_setting else None,
             "lotteryTriggerScriptId": self.lottery_trigger_script_id,
-            "choicePrizeTableScriptId": self.choice_prize_table_script_id,
             "logSetting": self.log_setting.to_dict() if self.log_setting else None,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
