@@ -20,9 +20,14 @@ from .model import *
 class DescribeNamespacesRequest(core.Gs2Request):
 
     context_stack: str = None
+    name_prefix: str = None
     page_token: str = None
     limit: int = None
 
+    def with_name_prefix(self, name_prefix: str) -> DescribeNamespacesRequest:
+        self.name_prefix = name_prefix
+        return self
+
     def with_page_token(self, page_token: str) -> DescribeNamespacesRequest:
         self.page_token = page_token
         return self
@@ -50,11 +55,13 @@ class DescribeNamespacesRequest(core.Gs2Request):
         if data is None:
             return None
         return DescribeNamespacesRequest()\
+            .with_name_prefix(data.get('namePrefix'))\
             .with_page_token(data.get('pageToken'))\
             .with_limit(data.get('limit'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
+            "namePrefix": self.name_prefix,
             "pageToken": self.page_token,
             "limit": self.limit,
         }
@@ -67,7 +74,6 @@ class CreateNamespaceRequest(core.Gs2Request):
     description: str = None
     transaction_setting: TransactionSetting = None
     lottery_trigger_script_id: str = None
-    choice_prize_table_script_id: str = None
     log_setting: LogSetting = None
     queue_namespace_id: str = None
     key_id: str = None
@@ -88,10 +94,6 @@ class CreateNamespaceRequest(core.Gs2Request):
         self.lottery_trigger_script_id = lottery_trigger_script_id
         return self
 
-    def with_choice_prize_table_script_id(self, choice_prize_table_script_id: str) -> CreateNamespaceRequest:
-        self.choice_prize_table_script_id = choice_prize_table_script_id
-        return self
-
     def with_log_setting(self, log_setting: LogSetting) -> CreateNamespaceRequest:
         self.log_setting = log_setting
         return self
@@ -127,7 +129,6 @@ class CreateNamespaceRequest(core.Gs2Request):
             .with_description(data.get('description'))\
             .with_transaction_setting(TransactionSetting.from_dict(data.get('transactionSetting')))\
             .with_lottery_trigger_script_id(data.get('lotteryTriggerScriptId'))\
-            .with_choice_prize_table_script_id(data.get('choicePrizeTableScriptId'))\
             .with_log_setting(LogSetting.from_dict(data.get('logSetting')))\
             .with_queue_namespace_id(data.get('queueNamespaceId'))\
             .with_key_id(data.get('keyId'))
@@ -138,7 +139,6 @@ class CreateNamespaceRequest(core.Gs2Request):
             "description": self.description,
             "transactionSetting": self.transaction_setting.to_dict() if self.transaction_setting else None,
             "lotteryTriggerScriptId": self.lottery_trigger_script_id,
-            "choicePrizeTableScriptId": self.choice_prize_table_script_id,
             "logSetting": self.log_setting.to_dict() if self.log_setting else None,
             "queueNamespaceId": self.queue_namespace_id,
             "keyId": self.key_id,
@@ -224,7 +224,6 @@ class UpdateNamespaceRequest(core.Gs2Request):
     description: str = None
     transaction_setting: TransactionSetting = None
     lottery_trigger_script_id: str = None
-    choice_prize_table_script_id: str = None
     log_setting: LogSetting = None
     queue_namespace_id: str = None
     key_id: str = None
@@ -245,10 +244,6 @@ class UpdateNamespaceRequest(core.Gs2Request):
         self.lottery_trigger_script_id = lottery_trigger_script_id
         return self
 
-    def with_choice_prize_table_script_id(self, choice_prize_table_script_id: str) -> UpdateNamespaceRequest:
-        self.choice_prize_table_script_id = choice_prize_table_script_id
-        return self
-
     def with_log_setting(self, log_setting: LogSetting) -> UpdateNamespaceRequest:
         self.log_setting = log_setting
         return self
@@ -284,7 +279,6 @@ class UpdateNamespaceRequest(core.Gs2Request):
             .with_description(data.get('description'))\
             .with_transaction_setting(TransactionSetting.from_dict(data.get('transactionSetting')))\
             .with_lottery_trigger_script_id(data.get('lotteryTriggerScriptId'))\
-            .with_choice_prize_table_script_id(data.get('choicePrizeTableScriptId'))\
             .with_log_setting(LogSetting.from_dict(data.get('logSetting')))\
             .with_queue_namespace_id(data.get('queueNamespaceId'))\
             .with_key_id(data.get('keyId'))
@@ -295,7 +289,6 @@ class UpdateNamespaceRequest(core.Gs2Request):
             "description": self.description,
             "transactionSetting": self.transaction_setting.to_dict() if self.transaction_setting else None,
             "lotteryTriggerScriptId": self.lottery_trigger_script_id,
-            "choicePrizeTableScriptId": self.choice_prize_table_script_id,
             "logSetting": self.log_setting.to_dict() if self.log_setting else None,
             "queueNamespaceId": self.queue_namespace_id,
             "keyId": self.key_id,
@@ -686,6 +679,7 @@ class DescribeLotteryModelMastersRequest(core.Gs2Request):
 
     context_stack: str = None
     namespace_name: str = None
+    name_prefix: str = None
     page_token: str = None
     limit: int = None
 
@@ -693,6 +687,10 @@ class DescribeLotteryModelMastersRequest(core.Gs2Request):
         self.namespace_name = namespace_name
         return self
 
+    def with_name_prefix(self, name_prefix: str) -> DescribeLotteryModelMastersRequest:
+        self.name_prefix = name_prefix
+        return self
+
     def with_page_token(self, page_token: str) -> DescribeLotteryModelMastersRequest:
         self.page_token = page_token
         return self
@@ -721,12 +719,14 @@ class DescribeLotteryModelMastersRequest(core.Gs2Request):
             return None
         return DescribeLotteryModelMastersRequest()\
             .with_namespace_name(data.get('namespaceName'))\
+            .with_name_prefix(data.get('namePrefix'))\
             .with_page_token(data.get('pageToken'))\
             .with_limit(data.get('limit'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
+            "namePrefix": self.name_prefix,
             "pageToken": self.page_token,
             "limit": self.limit,
         }
@@ -992,6 +992,7 @@ class DescribePrizeTableMastersRequest(core.Gs2Request):
 
     context_stack: str = None
     namespace_name: str = None
+    name_prefix: str = None
     page_token: str = None
     limit: int = None
 
@@ -999,6 +1000,10 @@ class DescribePrizeTableMastersRequest(core.Gs2Request):
         self.namespace_name = namespace_name
         return self
 
+    def with_name_prefix(self, name_prefix: str) -> DescribePrizeTableMastersRequest:
+        self.name_prefix = name_prefix
+        return self
+
     def with_page_token(self, page_token: str) -> DescribePrizeTableMastersRequest:
         self.page_token = page_token
         return self
@@ -1027,12 +1032,14 @@ class DescribePrizeTableMastersRequest(core.Gs2Request):
             return None
         return DescribePrizeTableMastersRequest()\
             .with_namespace_name(data.get('namespaceName'))\
+            .with_name_prefix(data.get('namePrefix'))\
             .with_page_token(data.get('pageToken'))\
             .with_limit(data.get('limit'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
+            "namePrefix": self.name_prefix,
             "pageToken": self.page_token,
             "limit": self.limit,
         }
