@@ -842,6 +842,89 @@ class GitHubCheckoutSetting(core.Gs2Model):
         }
 
 
+class TransactionSetting(core.Gs2Model):
+    enable_auto_run: bool = None
+    enable_atomic_commit: bool = None
+    transaction_use_distributor: bool = None
+    commit_script_result_in_use_distributor: bool = None
+    acquire_action_use_job_queue: bool = None
+    distributor_namespace_id: str = None
+    key_id: str = None
+    queue_namespace_id: str = None
+
+    def with_enable_auto_run(self, enable_auto_run: bool) -> TransactionSetting:
+        self.enable_auto_run = enable_auto_run
+        return self
+
+    def with_enable_atomic_commit(self, enable_atomic_commit: bool) -> TransactionSetting:
+        self.enable_atomic_commit = enable_atomic_commit
+        return self
+
+    def with_transaction_use_distributor(self, transaction_use_distributor: bool) -> TransactionSetting:
+        self.transaction_use_distributor = transaction_use_distributor
+        return self
+
+    def with_commit_script_result_in_use_distributor(self, commit_script_result_in_use_distributor: bool) -> TransactionSetting:
+        self.commit_script_result_in_use_distributor = commit_script_result_in_use_distributor
+        return self
+
+    def with_acquire_action_use_job_queue(self, acquire_action_use_job_queue: bool) -> TransactionSetting:
+        self.acquire_action_use_job_queue = acquire_action_use_job_queue
+        return self
+
+    def with_distributor_namespace_id(self, distributor_namespace_id: str) -> TransactionSetting:
+        self.distributor_namespace_id = distributor_namespace_id
+        return self
+
+    def with_key_id(self, key_id: str) -> TransactionSetting:
+        self.key_id = key_id
+        return self
+
+    def with_queue_namespace_id(self, queue_namespace_id: str) -> TransactionSetting:
+        self.queue_namespace_id = queue_namespace_id
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[TransactionSetting]:
+        if data is None:
+            return None
+        return TransactionSetting()\
+            .with_enable_auto_run(data.get('enableAutoRun'))\
+            .with_enable_atomic_commit(data.get('enableAtomicCommit'))\
+            .with_transaction_use_distributor(data.get('transactionUseDistributor'))\
+            .with_commit_script_result_in_use_distributor(data.get('commitScriptResultInUseDistributor'))\
+            .with_acquire_action_use_job_queue(data.get('acquireActionUseJobQueue'))\
+            .with_distributor_namespace_id(data.get('distributorNamespaceId'))\
+            .with_key_id(data.get('keyId'))\
+            .with_queue_namespace_id(data.get('queueNamespaceId'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "enableAutoRun": self.enable_auto_run,
+            "enableAtomicCommit": self.enable_atomic_commit,
+            "transactionUseDistributor": self.transaction_use_distributor,
+            "commitScriptResultInUseDistributor": self.commit_script_result_in_use_distributor,
+            "acquireActionUseJobQueue": self.acquire_action_use_job_queue,
+            "distributorNamespaceId": self.distributor_namespace_id,
+            "keyId": self.key_id,
+            "queueNamespaceId": self.queue_namespace_id,
+        }
+
+
 class LogSetting(core.Gs2Model):
     logging_namespace_id: str = None
 
@@ -880,6 +963,7 @@ class NotificationSetting(core.Gs2Model):
     gateway_namespace_id: str = None
     enable_transfer_mobile_notification: bool = None
     sound: str = None
+    enable: str = None
 
     def with_gateway_namespace_id(self, gateway_namespace_id: str) -> NotificationSetting:
         self.gateway_namespace_id = gateway_namespace_id
@@ -893,6 +977,10 @@ class NotificationSetting(core.Gs2Model):
         self.sound = sound
         return self
 
+    def with_enable(self, enable: str) -> NotificationSetting:
+        self.enable = enable
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -914,13 +1002,15 @@ class NotificationSetting(core.Gs2Model):
         return NotificationSetting()\
             .with_gateway_namespace_id(data.get('gatewayNamespaceId'))\
             .with_enable_transfer_mobile_notification(data.get('enableTransferMobileNotification'))\
-            .with_sound(data.get('sound'))
+            .with_sound(data.get('sound'))\
+            .with_enable(data.get('enable'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "gatewayNamespaceId": self.gateway_namespace_id,
             "enableTransferMobileNotification": self.enable_transfer_mobile_notification,
             "sound": self.sound,
+            "enable": self.enable,
         }
 
 
@@ -2110,6 +2200,7 @@ class Namespace(core.Gs2Model):
     namespace_id: str = None
     name: str = None
     description: str = None
+    transaction_setting: TransactionSetting = None
     enable_rating: bool = None
     enable_disconnect_detection: str = None
     disconnect_detection_timeout_seconds: int = None
@@ -2144,6 +2235,10 @@ class Namespace(core.Gs2Model):
         self.description = description
         return self
 
+    def with_transaction_setting(self, transaction_setting: TransactionSetting) -> Namespace:
+        self.transaction_setting = transaction_setting
+        return self
+
     def with_enable_rating(self, enable_rating: bool) -> Namespace:
         self.enable_rating = enable_rating
         return self
@@ -2293,6 +2388,7 @@ class Namespace(core.Gs2Model):
             .with_namespace_id(data.get('namespaceId'))\
             .with_name(data.get('name'))\
             .with_description(data.get('description'))\
+            .with_transaction_setting(TransactionSetting.from_dict(data.get('transactionSetting')))\
             .with_enable_rating(data.get('enableRating'))\
             .with_enable_disconnect_detection(data.get('enableDisconnectDetection'))\
             .with_disconnect_detection_timeout_seconds(data.get('disconnectDetectionTimeoutSeconds'))\
@@ -2320,6 +2416,7 @@ class Namespace(core.Gs2Model):
             "namespaceId": self.namespace_id,
             "name": self.name,
             "description": self.description,
+            "transactionSetting": self.transaction_setting.to_dict() if self.transaction_setting else None,
             "enableRating": self.enable_rating,
             "enableDisconnectDetection": self.enable_disconnect_detection,
             "disconnectDetectionTimeoutSeconds": self.disconnect_detection_timeout_seconds,
