@@ -717,6 +717,7 @@ class LayerModelMaster(core.Gs2Model):
     metadata: str = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_layer_model_master_id(self, layer_model_master_id: str) -> LayerModelMaster:
         self.layer_model_master_id = layer_model_master_id
@@ -742,6 +743,10 @@ class LayerModelMaster(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> LayerModelMaster:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -833,7 +838,8 @@ class LayerModelMaster(core.Gs2Model):
             .with_description(data.get('description'))\
             .with_metadata(data.get('metadata'))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -843,6 +849,7 @@ class LayerModelMaster(core.Gs2Model):
             "metadata": self.metadata,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -968,6 +975,7 @@ class AreaModelMaster(core.Gs2Model):
     metadata: str = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_area_model_master_id(self, area_model_master_id: str) -> AreaModelMaster:
         self.area_model_master_id = area_model_master_id
@@ -993,6 +1001,10 @@ class AreaModelMaster(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> AreaModelMaster:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -1072,7 +1084,8 @@ class AreaModelMaster(core.Gs2Model):
             .with_description(data.get('description'))\
             .with_metadata(data.get('metadata'))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1082,6 +1095,7 @@ class AreaModelMaster(core.Gs2Model):
             "metadata": self.metadata,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -1184,9 +1198,9 @@ class AreaModel(core.Gs2Model):
             .with_area_model_id(data.get('areaModelId'))\
             .with_name(data.get('name'))\
             .with_metadata(data.get('metadata'))\
-            .with_layer_models([
+            .with_layer_models(None if data.get('layerModels') is None else [
                 LayerModel.from_dict(data.get('layerModels')[i])
-                for i in range(len(data.get('layerModels')) if data.get('layerModels') else 0)
+                for i in range(len(data.get('layerModels')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
@@ -1194,9 +1208,9 @@ class AreaModel(core.Gs2Model):
             "areaModelId": self.area_model_id,
             "name": self.name,
             "metadata": self.metadata,
-            "layerModels": [
+            "layerModels": None if self.layer_models is None else [
                 self.layer_models[i].to_dict() if self.layer_models[i] else None
-                for i in range(len(self.layer_models) if self.layer_models else 0)
+                for i in range(len(self.layer_models))
             ],
         }
 
@@ -1208,6 +1222,7 @@ class Namespace(core.Gs2Model):
     log_setting: LogSetting = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_namespace_id(self, namespace_id: str) -> Namespace:
         self.namespace_id = namespace_id
@@ -1233,6 +1248,10 @@ class Namespace(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Namespace:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -1300,7 +1319,8 @@ class Namespace(core.Gs2Model):
             .with_description(data.get('description'))\
             .with_log_setting(LogSetting.from_dict(data.get('logSetting')))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1310,4 +1330,5 @@ class Namespace(core.Gs2Model):
             "logSetting": self.log_setting.to_dict() if self.log_setting else None,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
\ No newline at end of file
