@@ -20,9 +20,14 @@ from .model import *
 class DescribeNamespacesRequest(core.Gs2Request):
 
     context_stack: str = None
+    name_prefix: str = None
     page_token: str = None
     limit: int = None
 
+    def with_name_prefix(self, name_prefix: str) -> DescribeNamespacesRequest:
+        self.name_prefix = name_prefix
+        return self
+
     def with_page_token(self, page_token: str) -> DescribeNamespacesRequest:
         self.page_token = page_token
         return self
@@ -50,11 +55,13 @@ class DescribeNamespacesRequest(core.Gs2Request):
         if data is None:
             return None
         return DescribeNamespacesRequest()\
+            .with_name_prefix(data.get('namePrefix'))\
             .with_page_token(data.get('pageToken'))\
             .with_limit(data.get('limit'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
+            "namePrefix": self.name_prefix,
             "pageToken": self.page_token,
             "limit": self.limit,
         }
@@ -65,6 +72,7 @@ class CreateNamespaceRequest(core.Gs2Request):
     context_stack: str = None
     name: str = None
     description: str = None
+    transaction_setting: TransactionSetting = None
     priority: str = None
     share_free: bool = None
     currency: str = None
@@ -84,6 +92,10 @@ class CreateNamespaceRequest(core.Gs2Request):
         self.description = description
         return self
 
+    def with_transaction_setting(self, transaction_setting: TransactionSetting) -> CreateNamespaceRequest:
+        self.transaction_setting = transaction_setting
+        return self
+
     def with_priority(self, priority: str) -> CreateNamespaceRequest:
         self.priority = priority
         return self
@@ -145,6 +157,7 @@ class CreateNamespaceRequest(core.Gs2Request):
         return CreateNamespaceRequest()\
             .with_name(data.get('name'))\
             .with_description(data.get('description'))\
+            .with_transaction_setting(TransactionSetting.from_dict(data.get('transactionSetting')))\
             .with_priority(data.get('priority'))\
             .with_share_free(data.get('shareFree'))\
             .with_currency(data.get('currency'))\
@@ -160,6 +173,7 @@ class CreateNamespaceRequest(core.Gs2Request):
         return {
             "name": self.name,
             "description": self.description,
+            "transactionSetting": self.transaction_setting.to_dict() if self.transaction_setting else None,
             "priority": self.priority,
             "shareFree": self.share_free,
             "currency": self.currency,
@@ -250,6 +264,7 @@ class UpdateNamespaceRequest(core.Gs2Request):
     context_stack: str = None
     namespace_name: str = None
     description: str = None
+    transaction_setting: TransactionSetting = None
     priority: str = None
     apple_key: str = None
     google_key: str = None
@@ -267,6 +282,10 @@ class UpdateNamespaceRequest(core.Gs2Request):
         self.description = description
         return self
 
+    def with_transaction_setting(self, transaction_setting: TransactionSetting) -> UpdateNamespaceRequest:
+        self.transaction_setting = transaction_setting
+        return self
+
     def with_priority(self, priority: str) -> UpdateNamespaceRequest:
         self.priority = priority
         return self
@@ -320,6 +339,7 @@ class UpdateNamespaceRequest(core.Gs2Request):
         return UpdateNamespaceRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_description(data.get('description'))\
+            .with_transaction_setting(TransactionSetting.from_dict(data.get('transactionSetting')))\
             .with_priority(data.get('priority'))\
             .with_apple_key(data.get('appleKey'))\
             .with_google_key(data.get('googleKey'))\
@@ -333,6 +353,7 @@ class UpdateNamespaceRequest(core.Gs2Request):
         return {
             "namespaceName": self.namespace_name,
             "description": self.description,
+            "transactionSetting": self.transaction_setting.to_dict() if self.transaction_setting else None,
             "priority": self.priority,
             "appleKey": self.apple_key,
             "googleKey": self.google_key,
