@@ -20,9 +20,14 @@ from .model import *
 class DescribeNamespacesRequest(core.Gs2Request):
 
     context_stack: str = None
+    name_prefix: str = None
     page_token: str = None
     limit: int = None
 
+    def with_name_prefix(self, name_prefix: str) -> DescribeNamespacesRequest:
+        self.name_prefix = name_prefix
+        return self
+
     def with_page_token(self, page_token: str) -> DescribeNamespacesRequest:
         self.page_token = page_token
         return self
@@ -50,11 +55,13 @@ class DescribeNamespacesRequest(core.Gs2Request):
         if data is None:
             return None
         return DescribeNamespacesRequest()\
+            .with_name_prefix(data.get('namePrefix'))\
             .with_page_token(data.get('pageToken'))\
             .with_limit(data.get('limit'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
+            "namePrefix": self.name_prefix,
             "pageToken": self.page_token,
             "limit": self.limit,
         }
@@ -700,6 +707,7 @@ class DescribeQuestGroupModelMastersRequest(core.Gs2Request):
 
     context_stack: str = None
     namespace_name: str = None
+    name_prefix: str = None
     page_token: str = None
     limit: int = None
 
@@ -707,6 +715,10 @@ class DescribeQuestGroupModelMastersRequest(core.Gs2Request):
         self.namespace_name = namespace_name
         return self
 
+    def with_name_prefix(self, name_prefix: str) -> DescribeQuestGroupModelMastersRequest:
+        self.name_prefix = name_prefix
+        return self
+
     def with_page_token(self, page_token: str) -> DescribeQuestGroupModelMastersRequest:
         self.page_token = page_token
         return self
@@ -735,12 +747,14 @@ class DescribeQuestGroupModelMastersRequest(core.Gs2Request):
             return None
         return DescribeQuestGroupModelMastersRequest()\
             .with_namespace_name(data.get('namespaceName'))\
+            .with_name_prefix(data.get('namePrefix'))\
             .with_page_token(data.get('pageToken'))\
             .with_limit(data.get('limit'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
+            "namePrefix": self.name_prefix,
             "pageToken": self.page_token,
             "limit": self.limit,
         }
@@ -965,6 +979,7 @@ class DescribeQuestModelMastersRequest(core.Gs2Request):
     context_stack: str = None
     namespace_name: str = None
     quest_group_name: str = None
+    name_prefix: str = None
     page_token: str = None
     limit: int = None
 
@@ -976,6 +991,10 @@ class DescribeQuestModelMastersRequest(core.Gs2Request):
         self.quest_group_name = quest_group_name
         return self
 
+    def with_name_prefix(self, name_prefix: str) -> DescribeQuestModelMastersRequest:
+        self.name_prefix = name_prefix
+        return self
+
     def with_page_token(self, page_token: str) -> DescribeQuestModelMastersRequest:
         self.page_token = page_token
         return self
@@ -1005,6 +1024,7 @@ class DescribeQuestModelMastersRequest(core.Gs2Request):
         return DescribeQuestModelMastersRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_quest_group_name(data.get('questGroupName'))\
+            .with_name_prefix(data.get('namePrefix'))\
             .with_page_token(data.get('pageToken'))\
             .with_limit(data.get('limit'))
 
@@ -1012,6 +1032,7 @@ class DescribeQuestModelMastersRequest(core.Gs2Request):
         return {
             "namespaceName": self.namespace_name,
             "questGroupName": self.quest_group_name,
+            "namePrefix": self.name_prefix,
             "pageToken": self.page_token,
             "limit": self.limit,
         }
