@@ -14,6 +14,7 @@
 
 from __future__ import annotations
 
+from ..core.model import *
 from .model import *
 
 
@@ -48,17 +49,17 @@ class DescribeNamespacesResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeNamespacesResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 Namespace.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
         }
@@ -234,6 +235,257 @@ class DeleteNamespaceResult(core.Gs2Result):
         }
 
 
+class GetServiceVersionResult(core.Gs2Result):
+    item: str = None
+
+    def with_item(self, item: str) -> GetServiceVersionResult:
+        self.item = item
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[GetServiceVersionResult]:
+        if data is None:
+            return None
+        return GetServiceVersionResult()\
+            .with_item(data.get('item'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "item": self.item,
+        }
+
+
+class DumpUserDataByUserIdResult(core.Gs2Result):
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[DumpUserDataByUserIdResult]:
+        if data is None:
+            return None
+        return DumpUserDataByUserIdResult()\
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+        }
+
+
+class CheckDumpUserDataByUserIdResult(core.Gs2Result):
+    url: str = None
+
+    def with_url(self, url: str) -> CheckDumpUserDataByUserIdResult:
+        self.url = url
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CheckDumpUserDataByUserIdResult]:
+        if data is None:
+            return None
+        return CheckDumpUserDataByUserIdResult()\
+            .with_url(data.get('url'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "url": self.url,
+        }
+
+
+class CleanUserDataByUserIdResult(core.Gs2Result):
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CleanUserDataByUserIdResult]:
+        if data is None:
+            return None
+        return CleanUserDataByUserIdResult()\
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+        }
+
+
+class CheckCleanUserDataByUserIdResult(core.Gs2Result):
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CheckCleanUserDataByUserIdResult]:
+        if data is None:
+            return None
+        return CheckCleanUserDataByUserIdResult()\
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+        }
+
+
+class PrepareImportUserDataByUserIdResult(core.Gs2Result):
+    upload_token: str = None
+    upload_url: str = None
+
+    def with_upload_token(self, upload_token: str) -> PrepareImportUserDataByUserIdResult:
+        self.upload_token = upload_token
+        return self
+
+    def with_upload_url(self, upload_url: str) -> PrepareImportUserDataByUserIdResult:
+        self.upload_url = upload_url
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[PrepareImportUserDataByUserIdResult]:
+        if data is None:
+            return None
+        return PrepareImportUserDataByUserIdResult()\
+            .with_upload_token(data.get('uploadToken'))\
+            .with_upload_url(data.get('uploadUrl'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "uploadToken": self.upload_token,
+            "uploadUrl": self.upload_url,
+        }
+
+
+class ImportUserDataByUserIdResult(core.Gs2Result):
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[ImportUserDataByUserIdResult]:
+        if data is None:
+            return None
+        return ImportUserDataByUserIdResult()\
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+        }
+
+
+class CheckImportUserDataByUserIdResult(core.Gs2Result):
+    url: str = None
+
+    def with_url(self, url: str) -> CheckImportUserDataByUserIdResult:
+        self.url = url
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CheckImportUserDataByUserIdResult]:
+        if data is None:
+            return None
+        return CheckImportUserDataByUserIdResult()\
+            .with_url(data.get('url'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "url": self.url,
+        }
+
+
 class DescribeCategoryModelsResult(core.Gs2Result):
     items: List[CategoryModel] = None
 
@@ -260,16 +512,16 @@ class DescribeCategoryModelsResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeCategoryModelsResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 CategoryModel.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
         }
 
@@ -339,17 +591,17 @@ class DescribeCategoryModelMastersResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeCategoryModelMastersResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 CategoryModelMaster.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
         }
@@ -590,17 +842,17 @@ class DescribeScoresResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeScoresResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 Score.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
         }
@@ -637,17 +889,17 @@ class DescribeScoresByUserIdResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeScoresByUserIdResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 Score.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
         }
@@ -752,17 +1004,17 @@ class DescribeRankingsResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeRankingsResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 Ranking.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
         }
@@ -799,17 +1051,17 @@ class DescribeRankingssByUserIdResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeRankingssByUserIdResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 Ranking.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
         }
@@ -841,16 +1093,16 @@ class DescribeNearRankingsResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeNearRankingsResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 Ranking.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
         }
 
@@ -1093,6 +1345,47 @@ class GetCurrentRankingMasterResult(core.Gs2Result):
         }
 
 
+class PreUpdateCurrentRankingMasterResult(core.Gs2Result):
+    upload_token: str = None
+    upload_url: str = None
+
+    def with_upload_token(self, upload_token: str) -> PreUpdateCurrentRankingMasterResult:
+        self.upload_token = upload_token
+        return self
+
+    def with_upload_url(self, upload_url: str) -> PreUpdateCurrentRankingMasterResult:
+        self.upload_url = upload_url
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[PreUpdateCurrentRankingMasterResult]:
+        if data is None:
+            return None
+        return PreUpdateCurrentRankingMasterResult()\
+            .with_upload_token(data.get('uploadToken'))\
+            .with_upload_url(data.get('uploadUrl'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "uploadToken": self.upload_token,
+            "uploadUrl": self.upload_url,
+        }
+
+
 class UpdateCurrentRankingMasterResult(core.Gs2Result):
     item: CurrentRankingMaster = None
 
@@ -1323,16 +1616,16 @@ class DescribeSubscribesByCategoryNameResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeSubscribesByCategoryNameResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 SubscribeUser.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
         }
 
@@ -1363,15 +1656,15 @@ class DescribeSubscribesByCategoryNameAndUserIdResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeSubscribesByCategoryNameAndUserIdResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 SubscribeUser.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
         }
\ No newline at end of file
