@@ -37,6 +37,8 @@ class Gs2RealtimeRestClient(rest.AbstractGs2RestClient):
         query_strings = {
             'contextStack': request.context_stack,
         }
+        if request.name_prefix is not None:
+            query_strings["namePrefix"] = request.name_prefix
         if request.page_token is not None:
             query_strings["pageToken"] = request.page_token
         if request.limit is not None:
@@ -115,6 +117,8 @@ class Gs2RealtimeRestClient(rest.AbstractGs2RestClient):
             body["name"] = request.name
         if request.description is not None:
             body["description"] = request.description
+        if request.transaction_setting is not None:
+            body["transactionSetting"] = request.transaction_setting.to_dict()
         if request.server_type is not None:
             body["serverType"] = request.server_type
         if request.server_spec is not None:
@@ -341,6 +345,8 @@ class Gs2RealtimeRestClient(rest.AbstractGs2RestClient):
         }
         if request.description is not None:
             body["description"] = request.description
+        if request.transaction_setting is not None:
+            body["transactionSetting"] = request.transaction_setting.to_dict()
         if request.server_type is not None:
             body["serverType"] = request.server_type
         if request.server_spec is not None:
