@@ -133,6 +133,7 @@ class TransactionSetting(core.Gs2Model):
     enable_auto_run: bool = None
     enable_atomic_commit: bool = None
     transaction_use_distributor: bool = None
+    commit_script_result_in_use_distributor: bool = None
     acquire_action_use_job_queue: bool = None
     distributor_namespace_id: str = None
     key_id: str = None
@@ -150,6 +151,10 @@ class TransactionSetting(core.Gs2Model):
         self.transaction_use_distributor = transaction_use_distributor
         return self
 
+    def with_commit_script_result_in_use_distributor(self, commit_script_result_in_use_distributor: bool) -> TransactionSetting:
+        self.commit_script_result_in_use_distributor = commit_script_result_in_use_distributor
+        return self
+
     def with_acquire_action_use_job_queue(self, acquire_action_use_job_queue: bool) -> TransactionSetting:
         self.acquire_action_use_job_queue = acquire_action_use_job_queue
         return self
@@ -188,6 +193,7 @@ class TransactionSetting(core.Gs2Model):
             .with_enable_auto_run(data.get('enableAutoRun'))\
             .with_enable_atomic_commit(data.get('enableAtomicCommit'))\
             .with_transaction_use_distributor(data.get('transactionUseDistributor'))\
+            .with_commit_script_result_in_use_distributor(data.get('commitScriptResultInUseDistributor'))\
             .with_acquire_action_use_job_queue(data.get('acquireActionUseJobQueue'))\
             .with_distributor_namespace_id(data.get('distributorNamespaceId'))\
             .with_key_id(data.get('keyId'))\
@@ -198,6 +204,7 @@ class TransactionSetting(core.Gs2Model):
             "enableAutoRun": self.enable_auto_run,
             "enableAtomicCommit": self.enable_atomic_commit,
             "transactionUseDistributor": self.transaction_use_distributor,
+            "commitScriptResultInUseDistributor": self.commit_script_result_in_use_distributor,
             "acquireActionUseJobQueue": self.acquire_action_use_job_queue,
             "distributorNamespaceId": self.distributor_namespace_id,
             "keyId": self.key_id,
