@@ -20,9 +20,14 @@ from .model import *
 class DescribeNamespacesRequest(core.Gs2Request):
 
     context_stack: str = None
+    name_prefix: str = None
     page_token: str = None
     limit: int = None
 
+    def with_name_prefix(self, name_prefix: str) -> DescribeNamespacesRequest:
+        self.name_prefix = name_prefix
+        return self
+
     def with_page_token(self, page_token: str) -> DescribeNamespacesRequest:
         self.page_token = page_token
         return self
@@ -50,11 +55,13 @@ class DescribeNamespacesRequest(core.Gs2Request):
         if data is None:
             return None
         return DescribeNamespacesRequest()\
+            .with_name_prefix(data.get('namePrefix'))\
             .with_page_token(data.get('pageToken'))\
             .with_limit(data.get('limit'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
+            "namePrefix": self.name_prefix,
             "pageToken": self.page_token,
             "limit": self.limit,
         }
@@ -65,6 +72,7 @@ class CreateNamespaceRequest(core.Gs2Request):
     context_stack: str = None
     name: str = None
     description: str = None
+    transaction_setting: TransactionSetting = None
     assume_user_id: str = None
     accept_version_script: ScriptSetting = None
     check_version_trigger_script_id: str = None
@@ -78,6 +86,10 @@ class CreateNamespaceRequest(core.Gs2Request):
         self.description = description
         return self
 
+    def with_transaction_setting(self, transaction_setting: TransactionSetting) -> CreateNamespaceRequest:
+        self.transaction_setting = transaction_setting
+        return self
+
     def with_assume_user_id(self, assume_user_id: str) -> CreateNamespaceRequest:
         self.assume_user_id = assume_user_id
         return self
@@ -115,6 +127,7 @@ class CreateNamespaceRequest(core.Gs2Request):
         return CreateNamespaceRequest()\
             .with_name(data.get('name'))\
             .with_description(data.get('description'))\
+            .with_transaction_setting(TransactionSetting.from_dict(data.get('transactionSetting')))\
             .with_assume_user_id(data.get('assumeUserId'))\
             .with_accept_version_script(ScriptSetting.from_dict(data.get('acceptVersionScript')))\
             .with_check_version_trigger_script_id(data.get('checkVersionTriggerScriptId'))\
@@ -124,6 +137,7 @@ class CreateNamespaceRequest(core.Gs2Request):
         return {
             "name": self.name,
             "description": self.description,
+            "transactionSetting": self.transaction_setting.to_dict() if self.transaction_setting else None,
             "assumeUserId": self.assume_user_id,
             "acceptVersionScript": self.accept_version_script.to_dict() if self.accept_version_script else None,
             "checkVersionTriggerScriptId": self.check_version_trigger_script_id,
@@ -208,6 +222,7 @@ class UpdateNamespaceRequest(core.Gs2Request):
     context_stack: str = None
     namespace_name: str = None
     description: str = None
+    transaction_setting: TransactionSetting = None
     assume_user_id: str = None
     accept_version_script: ScriptSetting = None
     check_version_trigger_script_id: str = None
@@ -221,6 +236,10 @@ class UpdateNamespaceRequest(core.Gs2Request):
         self.description = description
         return self
 
+    def with_transaction_setting(self, transaction_setting: TransactionSetting) -> UpdateNamespaceRequest:
+        self.transaction_setting = transaction_setting
+        return self
+
     def with_assume_user_id(self, assume_user_id: str) -> UpdateNamespaceRequest:
         self.assume_user_id = assume_user_id
         return self
@@ -258,6 +277,7 @@ class UpdateNamespaceRequest(core.Gs2Request):
         return UpdateNamespaceRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_description(data.get('description'))\
+            .with_transaction_setting(TransactionSetting.from_dict(data.get('transactionSetting')))\
             .with_assume_user_id(data.get('assumeUserId'))\
             .with_accept_version_script(ScriptSetting.from_dict(data.get('acceptVersionScript')))\
             .with_check_version_trigger_script_id(data.get('checkVersionTriggerScriptId'))\
@@ -267,6 +287,7 @@ class UpdateNamespaceRequest(core.Gs2Request):
         return {
             "namespaceName": self.namespace_name,
             "description": self.description,
+            "transactionSetting": self.transaction_setting.to_dict() if self.transaction_setting else None,
             "assumeUserId": self.assume_user_id,
             "acceptVersionScript": self.accept_version_script.to_dict() if self.accept_version_script else None,
             "checkVersionTriggerScriptId": self.check_version_trigger_script_id,
@@ -658,6 +679,7 @@ class DescribeVersionModelMastersRequest(core.Gs2Request):
 
     context_stack: str = None
     namespace_name: str = None
+    name_prefix: str = None
     page_token: str = None
     limit: int = None
 
@@ -665,6 +687,10 @@ class DescribeVersionModelMastersRequest(core.Gs2Request):
         self.namespace_name = namespace_name
         return self
 
+    def with_name_prefix(self, name_prefix: str) -> DescribeVersionModelMastersRequest:
+        self.name_prefix = name_prefix
+        return self
+
     def with_page_token(self, page_token: str) -> DescribeVersionModelMastersRequest:
         self.page_token = page_token
         return self
@@ -693,12 +719,14 @@ class DescribeVersionModelMastersRequest(core.Gs2Request):
             return None
         return DescribeVersionModelMastersRequest()\
             .with_namespace_name(data.get('namespaceName'))\
+            .with_name_prefix(data.get('namePrefix'))\
             .with_page_token(data.get('pageToken'))\
             .with_limit(data.get('limit'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
+            "namePrefix": self.name_prefix,
             "pageToken": self.page_token,
             "limit": self.limit,
         }
