@@ -14,6 +14,7 @@
 
 from __future__ import annotations
 
+from ..core.model import *
 from .model import *
 
 
@@ -48,17 +49,17 @@ class DescribeNamespacesResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeNamespacesResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 Namespace.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
         }
@@ -234,6 +235,257 @@ class DeleteNamespaceResult(core.Gs2Result):
         }
 
 
+class GetServiceVersionResult(core.Gs2Result):
+    item: str = None
+
+    def with_item(self, item: str) -> GetServiceVersionResult:
+        self.item = item
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[GetServiceVersionResult]:
+        if data is None:
+            return None
+        return GetServiceVersionResult()\
+            .with_item(data.get('item'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "item": self.item,
+        }
+
+
+class DumpUserDataByUserIdResult(core.Gs2Result):
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[DumpUserDataByUserIdResult]:
+        if data is None:
+            return None
+        return DumpUserDataByUserIdResult()\
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+        }
+
+
+class CheckDumpUserDataByUserIdResult(core.Gs2Result):
+    url: str = None
+
+    def with_url(self, url: str) -> CheckDumpUserDataByUserIdResult:
+        self.url = url
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CheckDumpUserDataByUserIdResult]:
+        if data is None:
+            return None
+        return CheckDumpUserDataByUserIdResult()\
+            .with_url(data.get('url'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "url": self.url,
+        }
+
+
+class CleanUserDataByUserIdResult(core.Gs2Result):
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CleanUserDataByUserIdResult]:
+        if data is None:
+            return None
+        return CleanUserDataByUserIdResult()\
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+        }
+
+
+class CheckCleanUserDataByUserIdResult(core.Gs2Result):
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CheckCleanUserDataByUserIdResult]:
+        if data is None:
+            return None
+        return CheckCleanUserDataByUserIdResult()\
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+        }
+
+
+class PrepareImportUserDataByUserIdResult(core.Gs2Result):
+    upload_token: str = None
+    upload_url: str = None
+
+    def with_upload_token(self, upload_token: str) -> PrepareImportUserDataByUserIdResult:
+        self.upload_token = upload_token
+        return self
+
+    def with_upload_url(self, upload_url: str) -> PrepareImportUserDataByUserIdResult:
+        self.upload_url = upload_url
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[PrepareImportUserDataByUserIdResult]:
+        if data is None:
+            return None
+        return PrepareImportUserDataByUserIdResult()\
+            .with_upload_token(data.get('uploadToken'))\
+            .with_upload_url(data.get('uploadUrl'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "uploadToken": self.upload_token,
+            "uploadUrl": self.upload_url,
+        }
+
+
+class ImportUserDataByUserIdResult(core.Gs2Result):
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[ImportUserDataByUserIdResult]:
+        if data is None:
+            return None
+        return ImportUserDataByUserIdResult()\
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+        }
+
+
+class CheckImportUserDataByUserIdResult(core.Gs2Result):
+    url: str = None
+
+    def with_url(self, url: str) -> CheckImportUserDataByUserIdResult:
+        self.url = url
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CheckImportUserDataByUserIdResult]:
+        if data is None:
+            return None
+        return CheckImportUserDataByUserIdResult()\
+            .with_url(data.get('url'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "url": self.url,
+        }
+
+
 class DescribeVersionModelMastersResult(core.Gs2Result):
     items: List[VersionModelMaster] = None
     next_page_token: str = None
@@ -265,17 +517,17 @@ class DescribeVersionModelMastersResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeVersionModelMastersResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 VersionModelMaster.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
         }
@@ -443,16 +695,16 @@ class DescribeVersionModelsResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeVersionModelsResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 VersionModel.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
         }
 
@@ -522,17 +774,17 @@ class DescribeAcceptVersionsResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeAcceptVersionsResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 AcceptVersion.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
         }
@@ -569,17 +821,17 @@ class DescribeAcceptVersionsByUserIdResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeAcceptVersionsByUserIdResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 AcceptVersion.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
         }
@@ -653,6 +905,74 @@ class AcceptByUserIdResult(core.Gs2Result):
         }
 
 
+class RejectResult(core.Gs2Result):
+    item: AcceptVersion = None
+
+    def with_item(self, item: AcceptVersion) -> RejectResult:
+        self.item = item
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[RejectResult]:
+        if data is None:
+            return None
+        return RejectResult()\
+            .with_item(AcceptVersion.from_dict(data.get('item')))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "item": self.item.to_dict() if self.item else None,
+        }
+
+
+class RejectByUserIdResult(core.Gs2Result):
+    item: AcceptVersion = None
+
+    def with_item(self, item: AcceptVersion) -> RejectByUserIdResult:
+        self.item = item
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[RejectByUserIdResult]:
+        if data is None:
+            return None
+        return RejectByUserIdResult()\
+            .with_item(AcceptVersion.from_dict(data.get('item')))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "item": self.item.to_dict() if self.item else None,
+        }
+
+
 class GetAcceptVersionResult(core.Gs2Result):
     item: AcceptVersion = None
 
@@ -826,25 +1146,25 @@ class CheckVersionResult(core.Gs2Result):
             return None
         return CheckVersionResult()\
             .with_project_token(data.get('projectToken'))\
-            .with_warnings([
+            .with_warnings(None if data.get('warnings') is None else [
                 Status.from_dict(data.get('warnings')[i])
-                for i in range(len(data.get('warnings')) if data.get('warnings') else 0)
+                for i in range(len(data.get('warnings')))
             ])\
-            .with_errors([
+            .with_errors(None if data.get('errors') is None else [
                 Status.from_dict(data.get('errors')[i])
-                for i in range(len(data.get('errors')) if data.get('errors') else 0)
+                for i in range(len(data.get('errors')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "projectToken": self.project_token,
-            "warnings": [
+            "warnings": None if self.warnings is None else [
                 self.warnings[i].to_dict() if self.warnings[i] else None
-                for i in range(len(self.warnings) if self.warnings else 0)
+                for i in range(len(self.warnings))
             ],
-            "errors": [
+            "errors": None if self.errors is None else [
                 self.errors[i].to_dict() if self.errors[i] else None
-                for i in range(len(self.errors) if self.errors else 0)
+                for i in range(len(self.errors))
             ],
         }
 
@@ -886,25 +1206,25 @@ class CheckVersionByUserIdResult(core.Gs2Result):
             return None
         return CheckVersionByUserIdResult()\
             .with_project_token(data.get('projectToken'))\
-            .with_warnings([
+            .with_warnings(None if data.get('warnings') is None else [
                 Status.from_dict(data.get('warnings')[i])
-                for i in range(len(data.get('warnings')) if data.get('warnings') else 0)
+                for i in range(len(data.get('warnings')))
             ])\
-            .with_errors([
+            .with_errors(None if data.get('errors') is None else [
                 Status.from_dict(data.get('errors')[i])
-                for i in range(len(data.get('errors')) if data.get('errors') else 0)
+                for i in range(len(data.get('errors')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "projectToken": self.project_token,
-            "warnings": [
+            "warnings": None if self.warnings is None else [
                 self.warnings[i].to_dict() if self.warnings[i] else None
-                for i in range(len(self.warnings) if self.warnings else 0)
+                for i in range(len(self.warnings))
             ],
-            "errors": [
+            "errors": None if self.errors is None else [
                 self.errors[i].to_dict() if self.errors[i] else None
-                for i in range(len(self.errors) if self.errors else 0)
+                for i in range(len(self.errors))
             ],
         }
 
@@ -1018,6 +1338,47 @@ class GetCurrentVersionMasterResult(core.Gs2Result):
         }
 
 
+class PreUpdateCurrentVersionMasterResult(core.Gs2Result):
+    upload_token: str = None
+    upload_url: str = None
+
+    def with_upload_token(self, upload_token: str) -> PreUpdateCurrentVersionMasterResult:
+        self.upload_token = upload_token
+        return self
+
+    def with_upload_url(self, upload_url: str) -> PreUpdateCurrentVersionMasterResult:
+        self.upload_url = upload_url
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[PreUpdateCurrentVersionMasterResult]:
+        if data is None:
+            return None
+        return PreUpdateCurrentVersionMasterResult()\
+            .with_upload_token(data.get('uploadToken'))\
+            .with_upload_url(data.get('uploadUrl'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "uploadToken": self.upload_token,
+            "uploadUrl": self.upload_url,
+        }
+
+
 class UpdateCurrentVersionMasterResult(core.Gs2Result):
     item: CurrentVersionMaster = None
 
